@@ -16,29 +16,27 @@
 NTTCIS Common Components
 """
 
-from typing import Dict
-
-import xml.etree.ElementTree as etree
 import re
-from functools import wraps
-from copy import deepcopy
-from base64 import b64encode
-from time import sleep
+import xml.etree.ElementTree as etree
 from io import BytesIO
+from copy import deepcopy
+from time import sleep
+from base64 import b64encode
+from typing import Dict
+from functools import wraps
+
+# TODO: use distutils.version when Travis CI fixed the pylint issue with version
+# from distutils.version import LooseVersion
+from libcloud.utils.py3 import b, httplib, basestring
+from libcloud.utils.xml import findtext
+from libcloud.common.base import RawResponse, XmlResponse, ConnectionUserAndKey
+from libcloud.compute.base import Node
+from libcloud.compute.types import LibcloudError, InvalidCredsError
 
 try:
-    from collections.abc import MutableSequence, Mapping
+    from collections.abc import Mapping, MutableSequence
 except ImportError:
-    from collections import MutableSequence, Mapping
-# TODO: use disutils.version when Travis CI fixed the pylint issue with version
-# from distutils.version import LooseVersion
-from libcloud.utils.py3 import httplib
-from libcloud.utils.py3 import b
-from libcloud.common.base import ConnectionUserAndKey, XmlResponse, RawResponse
-from libcloud.compute.base import Node
-from libcloud.utils.py3 import basestring
-from libcloud.utils.xml import findtext
-from libcloud.compute.types import LibcloudError, InvalidCredsError
+    from collections.abc import Mapping, MutableSequence
 
 
 # Roadmap / TODO:
@@ -189,84 +187,6 @@ API_ENDPOINTS = {
         "host": "iaas-api-ca.cisco-ccs.com",
         "vendor": "Cisco",
     },
-    "med1-il": {
-        "name": "Israel (IL)",
-        "host": "api.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "med1-na": {
-        "name": "North America (NA)",
-        "host": "api-na.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "med1-eu": {
-        "name": "Europe (EU)",
-        "host": "api-eu.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "med1-au": {
-        "name": "Australia (AU)",
-        "host": "api-au.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "med1-af": {
-        "name": "Africa (AF)",
-        "host": "api-af.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "med1-ap": {
-        "name": "Asia Pacific (AP)",
-        "host": "api-ap.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "med1-latam": {
-        "name": "South America (LATAM)",
-        "host": "api-sa.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "med1-canada": {
-        "name": "Canada (CA)",
-        "host": "api-ca.cloud.med-1.com",
-        "vendor": "Med-1",
-    },
-    "indosat-id": {
-        "name": "Indonesia (ID)",
-        "host": "iaas-api.indosat.com",
-        "vendor": "Indosat",
-    },
-    "indosat-na": {
-        "name": "North America (NA)",
-        "host": "iaas-usapi.indosat.com",
-        "vendor": "Indosat",
-    },
-    "indosat-eu": {
-        "name": "Europe (EU)",
-        "host": "iaas-euapi.indosat.com",
-        "vendor": "Indosat",
-    },
-    "indosat-au": {
-        "name": "Australia (AU)",
-        "host": "iaas-auapi.indosat.com",
-        "vendor": "Indosat",
-    },
-    "indosat-af": {
-        "name": "Africa (AF)",
-        "host": "iaas-afapi.indosat.com",
-        "vendor": "Indosat",
-    },
-    "bsnl-in": {"name": "India (IN)", "host": "api.bsnlcloud.com", "vendor": "BSNL"},
-    "bsnl-na": {
-        "name": "North America (NA)",
-        "host": "usapi.bsnlcloud.com",
-        "vendor": "BSNL",
-    },
-    "bsnl-eu": {"name": "Europe (EU)", "host": "euapi.bsnlcloud.com", "vendor": "BSNL"},
-    "bsnl-au": {
-        "name": "Australia (AU)",
-        "host": "auapi.bsnlcloud.com",
-        "vendor": "BSNL",
-    },
-    "bsnl-af": {"name": "Africa (AF)", "host": "afapi.bsnlcloud.com", "vendor": "BSNL"},
 }
 
 # Default API end-point for the base connection class.
@@ -325,18 +245,19 @@ def dd_object_to_id(obj, obj_type, id_value="id"):
         return obj
     else:
         raise TypeError(
-            "Invalid type %s looking for basestring or %s"
-            % (type(obj).__name__, obj_type.__name__)
+            "Invalid type {} looking for basestring or {}".format(
+                type(obj).__name__, obj_type.__name__
+            )
         )
 
 
-# TODO: use disutils.version when Travis CI fixed the pylint issue with version
+# TODO: use distutils.version when Travis CI fixed the pylint issue with version
 #       This is a temporary workaround.
 def LooseVersion(version):
     return float(version)
 
 
-class NetworkDomainServicePlan(object):
+class NetworkDomainServicePlan:
     ESSENTIALS = "ESSENTIALS"
     ADVANCED = "ADVANCED"
 
@@ -363,13 +284,9 @@ class NttCisResponse(XmlResponse):
                 message = findtext(body, message[0], message[1])
                 if message is not None:
                     break
-            raise NttCisAPIException(
-                code=code, msg=message, driver=self.connection.driver
-            )
+            raise NttCisAPIException(code=code, msg=message, driver=self.connection.driver)
         if self.status is not httplib.OK:
-            raise NttCisAPIException(
-                code=self.status, msg=body, driver=self.connection.driver
-            )
+            raise NttCisAPIException(code=self.status, msg=body, driver=self.connection.driver)
 
         return self.body
 
@@ -381,10 +298,10 @@ class NttCisAPIException(LibcloudError):
         self.driver = driver
 
     def __str__(self):
-        return "%s: %s" % (self.code, self.msg)
+        return "{}: {}".format(self.code, self.msg)
 
     def __repr__(self):
-        return "<NttCisAPIException: code='%s', msg='%s'>" % (self.code, self.msg)
+        return "<NttCisAPIException: code='{}', msg='{}'>".format(self.code, self.msg)
 
 
 class NttCisConnection(ConnectionUserAndKey):
@@ -424,7 +341,7 @@ class NttCisConnection(ConnectionUserAndKey):
         api_version=None,
         **conn_kwargs,
     ):
-        super(NttCisConnection, self).__init__(
+        super().__init__(
             user_id=user_id,
             key=key,
             secure=secure,
@@ -463,37 +380,35 @@ class NttCisConnection(ConnectionUserAndKey):
 
     def add_default_headers(self, headers):
         headers["Authorization"] = "Basic %s" % b64encode(
-            b("%s:%s" % (self.user_id, self.key))
+            b("{}:{}".format(self.user_id, self.key))
         ).decode("utf-8")
         headers["Content-Type"] = "application/xml"
         return headers
 
     def request_api_1(self, action, params=None, data="", headers=None, method="GET"):
-        action = "%s/%s/%s" % (self.api_path_version_1, self.api_version_1, action)
+        action = "{}/{}/{}".format(self.api_path_version_1, self.api_version_1, action)
 
-        return super(NttCisConnection, self).request(
+        return super().request(
             action=action, params=params, data=data, method=method, headers=headers
         )
 
-    def request_api_2(
-        self, path, action, params=None, data="", headers=None, method="GET"
-    ):
-        action = "%s/%s/%s/%s" % (
+    def request_api_2(self, path, action, params=None, data="", headers=None, method="GET"):
+        action = "{}/{}/{}/{}".format(
             self.api_path_version_2,
             self.active_api_version,
             path,
             action,
         )
 
-        return super(NttCisConnection, self).request(
+        return super().request(
             action=action, params=params, data=data, method=method, headers=headers
         )
 
     def raw_request_with_orgId_api_1(
         self, action, params=None, data="", headers=None, method="GET"
     ):
-        action = "%s/%s" % (self.get_resource_path_api_1(), action)
-        return super(NttCisConnection, self).request(
+        action = "{}/{}".format(self.get_resource_path_api_1(), action)
+        return super().request(
             action=action,
             params=params,
             data=data,
@@ -502,21 +417,17 @@ class NttCisConnection(ConnectionUserAndKey):
             raw=True,
         )
 
-    def request_with_orgId_api_1(
-        self, action, params=None, data="", headers=None, method="GET"
-    ):
-        action = "%s/%s" % (self.get_resource_path_api_1(), action)
+    def request_with_orgId_api_1(self, action, params=None, data="", headers=None, method="GET"):
+        action = "{}/{}".format(self.get_resource_path_api_1(), action)
 
-        return super(NttCisConnection, self).request(
+        return super().request(
             action=action, params=params, data=data, method=method, headers=headers
         )
 
-    def request_with_orgId_api_2(
-        self, action, params=None, data="", headers=None, method="GET"
-    ):
-        action = "%s/%s" % (self.get_resource_path_api_2(), action)
+    def request_with_orgId_api_2(self, action, params=None, data="", headers=None, method="GET"):
+        action = "{}/{}".format(self.get_resource_path_api_2(), action)
 
-        return super(NttCisConnection, self).request(
+        return super().request(
             action=action, params=params, data=data, method=method, headers=headers
         )
 
@@ -552,9 +463,7 @@ class NttCisConnection(ConnectionUserAndKey):
             params = {}
         params["pageSize"] = page_size
 
-        resp = self.request_with_orgId_api_2(
-            action, params, data, headers, method
-        ).object
+        resp = self.request_with_orgId_api_2(action, params, data, headers, method).object
         yield resp
         if len(resp) <= 0:
             return
@@ -565,9 +474,7 @@ class NttCisConnection(ConnectionUserAndKey):
 
         while int(pcount) >= int(psize):
             params["pageNumber"] = int(pnumber) + 1
-            resp = self.request_with_orgId_api_2(
-                action, params, data, headers, method
-            ).object
+            resp = self.request_with_orgId_api_2(action, params, data, headers, method).object
             pcount = resp.get("pageCount")  # pylint: disable=no-member
             psize = resp.get("pageSize")  # pylint: disable=no-member
             pnumber = resp.get("pageNumber")  # pylint: disable=no-member
@@ -579,7 +486,7 @@ class NttCisConnection(ConnectionUserAndKey):
         resources that require a full path instead of just an ID, such as
         networks, and customer snapshots.
         """
-        return "%s/%s/%s" % (
+        return "{}/{}/{}".format(
             self.api_path_version_1,
             self.api_version_1,
             self._get_orgId(),
@@ -591,7 +498,7 @@ class NttCisConnection(ConnectionUserAndKey):
         resources that require a full path instead of just an ID, such as
         networks, and customer snapshots.
         """
-        return "%s/%s/%s" % (
+        return "{}/{}/{}".format(
             self.api_path_version_2,
             self.active_api_version,
             self._get_orgId(),
@@ -673,7 +580,7 @@ class NttCisConnection(ConnectionUserAndKey):
         )
 
 
-class NttCisAccountDetails(object):
+class NttCisAccountDetails:
     """
     NTTCIS account class details
     """
@@ -686,7 +593,7 @@ class NttCisAccountDetails(object):
         self.email = email
 
 
-class NttCisStatus(object):
+class NttCisStatus:
     """
     NTTCIS API pending operation status class
         action, request_time, user_name, number_of_steps, update_time,
@@ -734,7 +641,7 @@ class NttCisStatus(object):
         )
 
 
-class NttCisNetwork(object):
+class NttCisNetwork:
     """
     NTTCIS network with location.
     """
@@ -762,7 +669,7 @@ class NttCisNetwork(object):
         )
 
 
-class NttCisNetworkDomain(object):
+class NttCisNetworkDomain:
     """
     NttCis network domain with location.
     """
@@ -789,7 +696,7 @@ class NttCisNetworkDomain(object):
         )
 
 
-class NttCisPublicIpBlock(object):
+class NttCisPublicIpBlock:
     """
     NTTCIS Public IP Block with location.
     """
@@ -803,13 +710,16 @@ class NttCisPublicIpBlock(object):
         self.status = status
 
     def __repr__(self):
-        return (
-            "<NttCisNetworkDomain: id=%s, base_ip=%s, "
-            "size=%s, location=%s, status=%s>"
-        ) % (self.id, self.base_ip, self.size, self.location, self.status)
+        return ("<NttCisNetworkDomain: id=%s, base_ip=%s, " "size=%s, location=%s, status=%s>") % (
+            self.id,
+            self.base_ip,
+            self.size,
+            self.location,
+            self.status,
+        )
 
 
-class NttCisServerCpuSpecification(object):
+class NttCisServerCpuSpecification:
     """
     A class that represents the specification of the CPU(s) for a
     node
@@ -841,7 +751,7 @@ class NttCisServerCpuSpecification(object):
         ) % (self.cpu_count, self.cores_per_socket, self.performance)
 
 
-class NttCisServerDisk(object):
+class NttCisServerDisk:
     """
     A class that represents the disk on a server
     """
@@ -875,7 +785,7 @@ class NttCisServerDisk(object):
         return ("<NttCisServerDisk: " "id=%s, size_gb=%s") % (self.id, self.size_gb)
 
 
-class NttCisScsiController(object):
+class NttCisScsiController:
     """
     A class that represents the disk on a server
     """
@@ -893,7 +803,7 @@ class NttCisScsiController(object):
         :param bus_number: The bus number occupied on the virtual hardware
         :type  bus_nubmer: ``str``
 
-        :param state: Curent state (i.e. NORMAL)
+        :param state: Current state (i.e. NORMAL)
         :type  speed: ``str``
 
         :param state: State of the disk (i.e. PENDING)
@@ -905,12 +815,15 @@ class NttCisScsiController(object):
         self.state = state
 
     def __repr__(self):
-        return (
-            "<NttCisScsiController: " "id=%s, adapter_type=%s, bus_number=%s, state=%s"
-        ) % (self.id, self.adapter_type, self.bus_number, self.state)
+        return ("<NttCisScsiController: " "id=%s, adapter_type=%s, bus_number=%s, state=%s") % (
+            self.id,
+            self.adapter_type,
+            self.bus_number,
+            self.state,
+        )
 
 
-class NttCisServerVMWareTools(object):
+class NttCisServerVMWareTools:
     """
     A class that represents the VMWareTools for a node
     """
@@ -934,14 +847,14 @@ class NttCisServerVMWareTools(object):
         self.api_version = api_version
 
     def __repr__(self):
-        return (
-            "<NttCisServerVMWareTools "
-            "status=%s, version_status=%s, "
-            "api_version=%s>"
-        ) % (self.status, self.version_status, self.api_version)
+        return ("<NttCisServerVMWareTools " "status=%s, version_status=%s, " "api_version=%s>") % (
+            self.status,
+            self.version_status,
+            self.api_version,
+        )
 
 
-class NttCisSnapshot(object):
+class NttCisSnapshot:
     """
     NTTCIS Class representing server snapshots
     """
@@ -987,7 +900,7 @@ class NttCisSnapshot(object):
         )
 
 
-class NttCisReservedIpAddress(object):
+class NttCisReservedIpAddress:
     """
     NTTCIS Rerverse IPv4 address
     """
@@ -1013,7 +926,7 @@ class NttCisReservedIpAddress(object):
         )
 
 
-class NttCisFirewallRule(object):
+class NttCisFirewallRule:
     """
     NTTCIS Firewall Rule for a network domain
     """
@@ -1090,7 +1003,7 @@ class NttCisFirewallAddress(object):
 """
 
 
-class NttCisFirewallAddress(object):
+class NttCisFirewallAddress:
     """
     The source or destination model in a firewall rule
     9/4/18: Editing Class to use with ex_create_firewall_rtule method.
@@ -1156,7 +1069,7 @@ class NttCisFirewallAddress(object):
         )
 
 
-class NttCisNatRule(object):
+class NttCisNatRule:
     """
     An IP NAT rule in a network domain
     """
@@ -1172,7 +1085,7 @@ class NttCisNatRule(object):
         return ("<NttCisNatRule: id=%s, status=%s>") % (self.id, self.status)
 
 
-class NttCisAntiAffinityRule(object):
+class NttCisAntiAffinityRule:
     """
     Anti-Affinity rule for NTTCIS
 
@@ -1197,7 +1110,7 @@ class NttCisAntiAffinityRule(object):
         return ("<NttCisAntiAffinityRule: id=%s>") % (self.id)
 
 
-class NttCisVlan(object):
+class NttCisVlan:
     """
     NTTCIS VLAN.
     """
@@ -1274,12 +1187,16 @@ class NttCisVlan(object):
         self.ipv6_gateway = ipv6_gateway
 
     def __repr__(self):
-        return (
-            "<NttCisVlan: id=%s, name=%s, " "description=%s, location=%s, status=%s>"
-        ) % (self.id, self.name, self.description, self.location, self.status)
+        return ("<NttCisVlan: id=%s, name=%s, " "description=%s, location=%s, status=%s>") % (
+            self.id,
+            self.name,
+            self.description,
+            self.location,
+            self.status,
+        )
 
 
-class NttCisPool(object):
+class NttCisPool:
     """
     NttCis VIP Pool.
     """
@@ -1340,7 +1257,7 @@ class NttCisPool(object):
         )
 
 
-class NttCisPoolMember(object):
+class NttCisPoolMember:
     """
     NTTCIS VIP Pool Member.
     """
@@ -1375,13 +1292,17 @@ class NttCisPoolMember(object):
         self.node_id = node_id
 
     def __repr__(self):
-        return (
-            "NttCisPoolMember: id=%s, name=%s, "
-            "ip=%s, status=%s, port=%s, node_id=%s>"
-        ) % (self.id, self.name, self.ip, self.status, self.port, self.node_id)
+        return ("NttCisPoolMember: id=%s, name=%s, " "ip=%s, status=%s, port=%s, node_id=%s>") % (
+            self.id,
+            self.name,
+            self.ip,
+            self.status,
+            self.port,
+            self.node_id,
+        )
 
 
-class NttCisVIPNode(object):
+class NttCisVIPNode:
     def __init__(
         self,
         id,
@@ -1431,7 +1352,7 @@ class NttCisVIPNode(object):
         )
 
 
-class NttCisVirtualListener(object):
+class NttCisVirtualListener:
     """
     NTTCIS Virtual Listener.
     """
@@ -1466,7 +1387,7 @@ class NttCisVirtualListener(object):
         )
 
 
-class NttCisDefaultHealthMonitor(object):
+class NttCisDefaultHealthMonitor:
     """
     A default health monitor for a VIP (node, pool or listener)
     """
@@ -1496,7 +1417,7 @@ class NttCisDefaultHealthMonitor(object):
         return ("<NttCisDefaultHealthMonitor: id=%s, name=%s>") % (self.id, self.name)
 
 
-class NttCisPersistenceProfile(object):
+class NttCisPersistenceProfile:
     """
     Each Persistence Profile declares the combination of Virtual Listener
     type and protocol with which it is
@@ -1530,7 +1451,7 @@ class NttCisPersistenceProfile(object):
         return ("NttCisPersistenceProfile: id=%s, name=%s>") % (self.id, self.name)
 
 
-class NttCisDefaultiRule(object):
+class NttCisDefaultiRule:
     """
     A default iRule for a network domain, can be applied to a listener
     """
@@ -1557,7 +1478,7 @@ class NttCisDefaultiRule(object):
         return ("<NttCisDefaultiRule: id=%s, name=%s>") % (self.id, self.name)
 
 
-class NttCisVirtualListenerCompatibility(object):
+class NttCisVirtualListenerCompatibility:
     """
     A compatibility preference for a persistence profile or iRule
     specifies which virtual listener types this profile or iRule can be
@@ -1575,7 +1496,7 @@ class NttCisVirtualListenerCompatibility(object):
         )
 
 
-class NttCisBackupDetails(object):
+class NttCisBackupDetails:
     """
     NTTCIS Backup Details represents information about
     a targets backups configuration
@@ -1607,7 +1528,7 @@ class NttCisBackupDetails(object):
         return ("<NttCisBackupDetails: id=%s>") % (self.asset_id)
 
 
-class NttCisBackupClient(object):
+class NttCisBackupClient:
     """
     An object that represents a backup client
     """
@@ -1661,7 +1582,7 @@ class NttCisBackupClient(object):
         return ("<NttCisBackupClient: id=%s>") % (self.id)
 
 
-class NttCisBackupClientAlert(object):
+class NttCisBackupClientAlert:
     """
     An alert for a backup client
     """
@@ -1684,7 +1605,7 @@ class NttCisBackupClientAlert(object):
         return ("<NttCisBackupClientAlert: trigger=%s>") % (self.trigger)
 
 
-class NttCisBackupClientRunningJob(object):
+class NttCisBackupClientRunningJob:
     """
     A running job for a given backup client
     """
@@ -1693,7 +1614,7 @@ class NttCisBackupClientRunningJob(object):
         """
         Initialize an instance of :class:`NttCisBackupClientRunningJob`
 
-        :param id: The unqiue ID of the job
+        :param id: The unique ID of the job
         :type  id: ``str``
 
         :param status: The status of the job i.e. Waiting
@@ -1710,7 +1631,7 @@ class NttCisBackupClientRunningJob(object):
         return ("<NttCisBackupClientRunningJob: id=%s>") % (self.id)
 
 
-class NttCisBackupClientType(object):
+class NttCisBackupClientType:
     """
     A client type object for backups
     """
@@ -1719,7 +1640,7 @@ class NttCisBackupClientType(object):
         """
         Initialize an instance of :class:`NttCisBackupClientType`
 
-        :param type: The type of client i.e. (FA.Linux, MySQL, ect.)
+        :param type: The type of client i.e. (FA.Linux, MySQL, etc.)
         :type  type: ``str``
 
         :param is_file_system: The name of the iRule
@@ -1736,7 +1657,7 @@ class NttCisBackupClientType(object):
         return ("<NttCisBackupClientType: type=%s>") % (self.type)
 
 
-class NttCisBackupStoragePolicy(object):
+class NttCisBackupStoragePolicy:
     """
     A representation of a storage policy
     """
@@ -1762,7 +1683,7 @@ class NttCisBackupStoragePolicy(object):
         return ("<NttCisBackupStoragePolicy: name=%s>") % (self.name)
 
 
-class NttCisBackupSchedulePolicy(object):
+class NttCisBackupSchedulePolicy:
     """
     A representation of a schedule policy
     """
@@ -1784,7 +1705,7 @@ class NttCisBackupSchedulePolicy(object):
         return ("<NttCisBackupSchedulePolicy: name=%s>") % (self.name)
 
 
-class NttCisTag(object):
+class NttCisTag:
     """
     A representation of a Tag in NTTCIS
     A Tag first must have a Tag Key, then an asset is tag with
@@ -1831,7 +1752,7 @@ class NttCisTag(object):
         )
 
 
-class NttCisTagKey(object):
+class NttCisTagKey:
     """
     A representation of a Tag Key in NTTCIS
     A tag key is required to tag an asset
@@ -1867,7 +1788,7 @@ class NttCisTagKey(object):
         return ("NttCisTagKey: id=%s name=%s>") % (self.id, self.name)
 
 
-class NttCisIpAddressList(object):
+class NttCisIpAddressList:
     """
     NttCis IP Address list
     """
@@ -1938,7 +1859,7 @@ class NttCisIpAddressList(object):
         )
 
 
-class NttCisChildIpAddressList(object):
+class NttCisChildIpAddressList:
     """
     NttCis Child IP Address list
     """
@@ -1958,10 +1879,10 @@ class NttCisChildIpAddressList(object):
         self.name = name
 
     def __repr__(self):
-        return "<NttCisChildIpAddressList: id=%s, name=%s>" % (self.id, self.name)
+        return "<NttCisChildIpAddressList: id={}, name={}>".format(self.id, self.name)
 
 
-class NttCisIpAddress(object):
+class NttCisIpAddress:
     """
     A representation of IP Address in NttCis
     """
@@ -1984,14 +1905,14 @@ class NttCisIpAddress(object):
         self.prefix_size = prefix_size
 
     def __repr__(self):
-        return "<NttCisIpAddress: begin=%s, end=%s, prefix_size=%s>" % (
+        return "<NttCisIpAddress: begin={}, end={}, prefix_size={}>".format(
             self.begin,
             self.end,
             self.prefix_size,
         )
 
 
-class NttCisPortList(object):
+class NttCisPortList:
     """
     NttCis Port list
     """
@@ -2055,7 +1976,7 @@ class NttCisPortList(object):
         )
 
 
-class NttCisChildPortList(object):
+class NttCisChildPortList:
     """
     NttCis Child Port list
     """
@@ -2075,10 +1996,10 @@ class NttCisChildPortList(object):
         self.name = name
 
     def __repr__(self):
-        return "<NttCisChildPortList: id=%s, name=%s>" % (self.id, self.name)
+        return "<NttCisChildPortList: id={}, name={}>".format(self.id, self.name)
 
 
-class NttCisPort(object):
+class NttCisPort:
     """
     A representation of Port in NTTCIS
     """
@@ -2097,10 +2018,10 @@ class NttCisPort(object):
         self.end = end
 
     def __repr__(self):
-        return "<NttCisPort: begin=%s, end=%s>" % (self.begin, self.end)
+        return "<NttCisPort: begin={}, end={}>".format(self.begin, self.end)
 
 
-class NttCisNic(object):
+class NttCisNic:
     """
     A representation of Network Adapter in NTTCIS
     """
@@ -2134,7 +2055,7 @@ class NttCisNic(object):
 # single authoritative source.
 
 
-class ClassFactory(object):
+class ClassFactory:
     pass
 
 
@@ -2183,11 +2104,7 @@ def processor(mapping, name=None):
     def handle_map(map, name):
         tmp = {}
         types = [type(x) for x in map.values()]
-        if (
-            XmlListConfig not in types
-            and XmlDictConfig not in types
-            and dict not in types
-        ):
+        if XmlListConfig not in types and XmlDictConfig not in types and dict not in types:
             return map
 
         elif XmlListConfig in types:
@@ -2327,9 +2244,7 @@ class XmlListConfig(list):
                     # property refers to an element used repeatedly
                     #  in the XML for data centers only
                     if "property" in element.tag:
-                        self.append(
-                            {element.attrib.get("name"): element.attrib.get("value")}
-                        )
+                        self.append({element.attrib.get("name"): element.attrib.get("value")})
                     else:
                         self.append(element.attrib)
             elif element.text:
@@ -2348,13 +2263,7 @@ class XmlDictConfig(dict):
     def __init__(self, parent_element):
         if parent_element.items():
             if "property" in parent_element.tag:
-                self.update(
-                    {
-                        parent_element.attrib.get("name"): parent_element.attrib.get(
-                            "value"
-                        )
-                    }
-                )
+                self.update({parent_element.attrib.get("name"): parent_element.attrib.get("value")})
             else:
                 self.update(dict(parent_element.items()))
         for element in parent_element:
@@ -2384,7 +2293,6 @@ class XmlDictConfig(dict):
                 # It is possible to have duplicate element tags.
                 # If so, convert to a dict of lists
                 if element.tag.split("}")[1] in self:
-
                     if isinstance(self[element.tag.split("}")[1]], list):
                         self[element.tag.split("}")[1]].append(dict(element.items()))
                     else:
