@@ -13,11 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Dict, Optional, Any
+from typing import Any, Dict, Optional
 
-from libcloud.common.base import ConnectionKey, JsonResponse
-from libcloud.compute.base import VolumeSnapshot
 from libcloud.utils.py3 import httplib
+from libcloud.common.base import JsonResponse, ConnectionKey
+from libcloud.compute.base import VolumeSnapshot
 
 __all__ = [
     "API_HOST",
@@ -38,7 +38,6 @@ DEFAULT_API_VERSION = "2"
 
 
 class VultrResponse(JsonResponse):
-
     objects = None
     error_dict = {}  # type: Dict[str, str]
     errors = None
@@ -48,17 +47,15 @@ class VultrResponse(JsonResponse):
         + " and matches your assigned key.",
         405: "Invalid HTTP method. Check that the method (POST|GET) matches"
         + " what the documentation indicates.",
-        412: "Request failed. Check the response body for a more detailed"
-        + " description.",
+        412: "Request failed. Check the response body for a more detailed" + " description.",
         500: "Internal server error. Try again at a later time.",
         503: "Rate limit hit. API requests are limited to an average of 1/s."
         + " Try your request again later.",
     }
 
     def __init__(self, response, connection):
-
         self.errors = []
-        super(VultrResponse, self).__init__(response=response, connection=connection)
+        super().__init__(response=response, connection=connection)
         self.objects, self.errors = self.parse_body_and_errors()
         if not self.success():
             raise self._make_excp(self.errors[0])
@@ -75,7 +72,7 @@ class VultrResponse(JsonResponse):
             self.error_dict["ERRORMESSAGE"] = self.ERROR_CODE_MAP[self.status]
             errors.append(self.error_dict)
 
-        js = super(VultrResponse, self).parse_body()
+        js = super().parse_body()
         if isinstance(js, dict):
             js = [js]
 
@@ -91,7 +88,6 @@ class VultrResponse(JsonResponse):
         return VultrException(error["ERRORCODE"], error["ERRORMESSAGE"])
 
     def success(self):
-
         return len(self.errors) == 0
 
 
@@ -207,7 +203,7 @@ class VultrNetwork:
         self.extra = extra or {}
 
     def __repr__(self):
-        return "<Vultrnetwork: id=%s cidr_block=%s location=%s>" % (
+        return "<Vultrnetwork: id={} cidr_block={} location={}>".format(
             self.id,
             self.cidr_block,
             self.location,
@@ -216,7 +212,7 @@ class VultrNetwork:
 
 class VultrNodeSnapshot(VolumeSnapshot):
     def __repr__(self):
-        return "<VultrNodeSnapshot id=%s size=%s driver=%s state=%s>" % (
+        return "<VultrNodeSnapshot id={} size={} driver={} state={}>".format(
             self.id,
             self.size,
             self.driver.name,
