@@ -12,24 +12,20 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import with_statement
 
-import re
 import os
+import re
 import time
 import platform
-import subprocess
 import mimetypes
-
+import subprocess
 from os.path import join as pjoin
 from collections import defaultdict
 
-from libcloud.utils.py3 import ET
-from libcloud.compute.base import NodeDriver, Node
-from libcloud.compute.base import NodeState
+from libcloud.utils.py3 import ET, ensure_string
+from libcloud.compute.base import Node, NodeState, NodeDriver
 from libcloud.compute.types import Provider
 from libcloud.utils.networking import is_public_subnet
-from libcloud.utils.py3 import ensure_string
 
 try:
     import libvirt
@@ -243,7 +239,7 @@ class LibvirtNodeDriver(NodeDriver):
         else:
             extension = ".png"
 
-        name = "screenshot-%s%s" % (int(time.time()), extension)
+        name = "screenshot-{}{}".format(int(time.time()), extension)
         file_path = pjoin(directory, name)
 
         with open(file_path, "wb") as fp:
@@ -352,17 +348,13 @@ class LibvirtNodeDriver(NodeDriver):
         arp_table = {}
         try:
             cmd = ["arp", "-an"]
-            child = subprocess.Popen(
-                cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
-            )
+            child = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             stdout, _ = child.communicate()
             arp_table = self._parse_ip_table_arp(arp_output=stdout)
         except OSError as e:
             if e.errno == 2:
                 cmd = ["ip", "neigh"]
-                child = subprocess.Popen(
-                    cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
-                )
+                child = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
                 stdout, _ = child.communicate()
                 arp_table = self._parse_ip_table_neigh(ip_output=stdout)
 
@@ -430,7 +422,7 @@ class LibvirtNodeDriver(NodeDriver):
         Sets up the regexp for parsing out IP addresses from the 'arp -an'
         command and pass it along to the parser function.
 
-        :return: Dictionary from the parsing funtion
+        :return: Dictionary from the parsing function
         :rtype: ``dict``
         """
         arp_regex = re.compile(r".*?\((.*?)\) at (.*?)\s+")
