@@ -22,18 +22,21 @@ OpenNebula.org driver.
 
 __docformat__ = "epytext"
 
-from base64 import b64encode
 import hashlib
+from base64 import b64encode
 
-from libcloud.utils.py3 import ET
-from libcloud.utils.py3 import httplib
-from libcloud.utils.py3 import next
-from libcloud.utils.py3 import b
-
-from libcloud.compute.base import NodeState, NodeDriver, Node, NodeLocation
-from libcloud.common.base import ConnectionUserAndKey, XmlResponse
-from libcloud.compute.base import NodeImage, NodeSize, StorageVolume
+from libcloud.utils.py3 import ET, b, next, httplib
+from libcloud.common.base import XmlResponse, ConnectionUserAndKey
 from libcloud.common.types import InvalidCredsError
+from libcloud.compute.base import (
+    Node,
+    NodeSize,
+    NodeImage,
+    NodeState,
+    NodeDriver,
+    NodeLocation,
+    StorageVolume,
+)
 from libcloud.compute.providers import Provider
 
 __all__ = [
@@ -57,7 +60,7 @@ API_PLAIN_AUTH = False
 DEFAULT_API_VERSION = "3.2"
 
 
-class ACTION(object):
+class ACTION:
     """
     All actions, except RESUME, only apply when the VM is in the "Running"
     state.
@@ -161,7 +164,7 @@ class OpenNebulaConnection(ConnectionUserAndKey):
     def __init__(self, *args, **kwargs):
         if "plain_auth" in kwargs:
             self.plain_auth = kwargs.pop("plain_auth")
-        super(OpenNebulaConnection, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def add_default_headers(self, headers):
         """
@@ -181,7 +184,7 @@ class OpenNebulaConnection(ConnectionUserAndKey):
         else:
             passwd = hashlib.sha1(b(self.key)).hexdigest()
         headers["Authorization"] = "Basic %s" % b64encode(
-            b("%s:%s" % (self.user_id, passwd))
+            b("{}:{}".format(self.user_id, passwd))
         ).decode("utf-8")
         return headers
 
@@ -191,10 +194,8 @@ class OpenNebulaNodeSize(NodeSize):
     NodeSize class for the OpenNebula.org driver.
     """
 
-    def __init__(
-        self, id, name, ram, disk, bandwidth, price, driver, cpu=None, vcpu=None
-    ):
-        super(OpenNebulaNodeSize, self).__init__(
+    def __init__(self, id, name, ram, disk, bandwidth, price, driver, cpu=None, vcpu=None):
+        super().__init__(
             id=id,
             name=name,
             ram=ram,
@@ -223,7 +224,7 @@ class OpenNebulaNodeSize(NodeSize):
         )
 
 
-class OpenNebulaNetwork(object):
+class OpenNebulaNetwork:
     """
     Provide a common interface for handling networks of all types.
 
@@ -260,10 +261,10 @@ class OpenNebulaNetwork(object):
 
         The hash is a function of an SHA1 hash of the network's ID and
         its driver which means that it should be unique between all
-        networks. In some subclasses (e.g. GoGrid) there is no ID
-        available so the public IP address is used. This means that,
-        unlike a properly done system UUID, the same UUID may mean a
-        different system install at a different time
+        networks. In some subclasses there is no ID available so the
+        public IP address is used. This means that, unlike a properly
+        done system UUID, the same UUID may mean a different system
+        install at a different time
 
         >>> from libcloud.network.drivers.dummy import DummyNetworkDriver
         >>> driver = DummyNetworkDriver()
@@ -277,12 +278,11 @@ class OpenNebulaNetwork(object):
         :rtype:  ``str``
         :return: Unique identifier for this instance.
         """
-        return hashlib.sha1(b("%s:%s" % (self.id, self.driver.type))).hexdigest()
+        return hashlib.sha1(b("{}:{}".format(self.id, self.driver.type))).hexdigest()
 
     def __repr__(self):
         return (
-            "<OpenNebulaNetwork: uuid=%s, name=%s, address=%s, size=%s, "
-            "provider=%s ...>"
+            "<OpenNebulaNetwork: uuid=%s, name=%s, address=%s, size=%s, " "provider=%s ...>"
         ) % (self.uuid, self.name, self.address, self.size, self.driver.name)
 
 
@@ -329,7 +329,7 @@ class OpenNebulaNodeDriver(NodeDriver):
                 raise NotImplementedError(
                     "No OpenNebulaNodeDriver found for API version %s" % (api_version)
                 )
-            return super(OpenNebulaNodeDriver, cls).__new__(cls)
+            return super().__new__(cls)
 
     def create_node(self, name, size, image, networks=None):
         """
@@ -366,9 +366,7 @@ class OpenNebulaNodeDriver(NodeDriver):
                         {"network": "%s" % (str(network.id)), "ip": network.address},
                     )
                 else:
-                    ET.SubElement(
-                        networkGroup, "NIC", {"network": "%s" % (str(network.id))}
-                    )
+                    ET.SubElement(networkGroup, "NIC", {"network": "%s" % (str(network.id))})
 
         xml = ET.tostring(compute)
         node = self.connection.request("/compute", method="POST", data=xml).object
@@ -496,7 +494,7 @@ class OpenNebulaNodeDriver(NodeDriver):
         images = []
         for element in object.findall("DISK"):
             image_id = element.attrib["href"].partition("/storage/")[2]
-            image = self.connection.request(("/storage/%s" % (image_id))).object
+            image = self.connection.request("/storage/%s" % (image_id)).object
             images.append(self._to_image(image))
 
         return images
@@ -534,9 +532,7 @@ class OpenNebulaNodeDriver(NodeDriver):
         networks = []
         for element in object.findall("NETWORK"):
             network_id = element.attrib["href"].partition("/network/")[2]
-            network_element = self.connection.request(
-                ("/network/%s" % (network_id))
-            ).object
+            network_element = self.connection.request("/network/%s" % (network_id)).object
             networks.append(self._to_network(network_element))
 
         return networks
@@ -575,7 +571,7 @@ class OpenNebulaNodeDriver(NodeDriver):
         computes = []
         for element in object.findall("COMPUTE"):
             compute_id = element.attrib["href"].partition("/compute/")[2]
-            compute = self.connection.request(("/compute/%s" % (compute_id))).object
+            compute = self.connection.request("/compute/%s" % (compute_id)).object
             computes.append(self._to_node(compute))
 
         return computes
@@ -724,9 +720,7 @@ class OpenNebula_2_0_NodeDriver(OpenNebulaNodeDriver):
 
             for network in networks:
                 nic = ET.SubElement(compute, "NIC")
-                ET.SubElement(
-                    nic, "NETWORK", {"href": "/network/%s" % (str(network.id))}
-                )
+                ET.SubElement(nic, "NETWORK", {"href": "/network/%s" % (str(network.id))})
                 if network.address:
                     ip_line = ET.SubElement(nic, "IP")
                     ip_line.text = network.address
@@ -815,7 +809,7 @@ class OpenNebula_2_0_NodeDriver(OpenNebulaNodeDriver):
         images = []
         for element in object.findall("STORAGE"):
             image_id = element.attrib["href"].partition("/storage/")[2]
-            image = self.connection.request(("/storage/%s" % (image_id))).object
+            image = self.connection.request("/storage/%s" % (image_id)).object
             images.append(self._to_image(image))
 
         return images
@@ -969,11 +963,7 @@ class OpenNebula_2_0_NodeDriver(OpenNebulaNodeDriver):
 
         try:
             return next(
-                (
-                    node_size
-                    for node_size in self.list_sizes()
-                    if node_size.name == instance_type.text
-                )
+                node_size for node_size in self.list_sizes() if node_size.name == instance_type.text
             )
         except StopIteration:
             return None
@@ -1180,9 +1170,7 @@ class OpenNebula_3_6_NodeDriver(OpenNebula_3_2_NodeDriver):
         vol_size.text = str(size)
 
         xml = ET.tostring(storage)
-        volume = self.connection.request(
-            "/storage", {"occixml": xml}, method="POST"
-        ).object
+        volume = self.connection.request("/storage", {"occixml": xml}, method="POST").object
 
         return self._to_volume(volume)
 
@@ -1262,9 +1250,7 @@ class OpenNebula_3_6_NodeDriver(OpenNebula_3_2_NodeDriver):
             storage_id = storage.attrib["href"].partition("/storage/")[2]
 
             volumes.append(
-                self._to_volume(
-                    self.connection.request("/storage/%s" % storage_id).object
-                )
+                self._to_volume(self.connection.request("/storage/%s" % storage_id).object)
             )
 
         return volumes
