@@ -13,43 +13,35 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import atexit
-import hmac
 import os
+import hmac
+import atexit
 from time import time
 from hashlib import sha1
 
-from libcloud.utils.py3 import httplib
-from libcloud.utils.py3 import urlencode
+from libcloud.utils.py3 import b, httplib, urlquote, urlencode
+from libcloud.common.base import Response, RawResponse
+from libcloud.utils.files import read_in_chunks
+from libcloud.common.types import LibcloudError, MalformedResponseError
+from libcloud.storage.base import Object, Container, StorageDriver
+from libcloud.storage.types import (
+    ObjectDoesNotExistError,
+    ObjectHashMismatchError,
+    ContainerIsNotEmptyError,
+    InvalidContainerNameError,
+    ContainerDoesNotExistError,
+    ContainerAlreadyExistsError,
+)
+from libcloud.common.openstack import OpenStackDriverMixin, OpenStackBaseConnection
+from libcloud.common.rackspace import AUTH_URL
+from libcloud.storage.providers import Provider
 
 try:
     import simplejson as json
 except ImportError:
     import json  # type: ignore
 
-from libcloud.utils.py3 import PY3
-from libcloud.utils.py3 import b
-from libcloud.utils.py3 import urlquote
-
-if PY3:
-    from io import FileIO as file
-
-from libcloud.utils.files import read_in_chunks
-from libcloud.common.types import MalformedResponseError, LibcloudError
-from libcloud.common.base import Response, RawResponse
-
-from libcloud.storage.providers import Provider
-from libcloud.storage.base import Object, Container, StorageDriver
-from libcloud.storage.types import ContainerAlreadyExistsError
-from libcloud.storage.types import ContainerDoesNotExistError
-from libcloud.storage.types import ContainerIsNotEmptyError
-from libcloud.storage.types import ObjectDoesNotExistError
-from libcloud.storage.types import ObjectHashMismatchError
-from libcloud.storage.types import InvalidContainerNameError
-from libcloud.common.openstack import OpenStackBaseConnection
-from libcloud.common.openstack import OpenStackDriverMixin
-
-from libcloud.common.rackspace import AUTH_URL
+from io import FileIO as file
 
 CDN_HOST = "cdn.clouddrive.com"
 API_VERSION = "v1.0"
@@ -117,9 +109,7 @@ class OpenStackSwiftConnection(OpenStackBaseConnection):
     def __init__(self, user_id, key, secure=True, **kwargs):
         # Ignore this for now
         kwargs.pop("use_internal_url", None)
-        super(OpenStackSwiftConnection, self).__init__(
-            user_id, key, secure=secure, **kwargs
-        )
+        super().__init__(user_id, key, secure=secure, **kwargs)
         self.api_version = API_VERSION
         self.accept_format = "application/json"
 
@@ -171,7 +161,7 @@ class OpenStackSwiftConnection(OpenStackBaseConnection):
         if method in ["POST", "PUT"] and "Content-Type" not in headers:
             headers.update({"Content-Type": "application/json; charset=UTF-8"})
 
-        return super(OpenStackSwiftConnection, self).request(
+        return super().request(
             action=action,
             params=params,
             data=data,
@@ -193,9 +183,7 @@ class CloudFilesConnection(OpenStackSwiftConnection):
     _auth_version = "2.0"
 
     def __init__(self, user_id, key, secure=True, use_internal_url=False, **kwargs):
-        super(CloudFilesConnection, self).__init__(
-            user_id, key, secure=secure, **kwargs
-        )
+        super().__init__(user_id, key, secure=secure, **kwargs)
         self.api_version = API_VERSION
         self.accept_format = "application/json"
         self.cdn_request = False
@@ -204,28 +192,22 @@ class CloudFilesConnection(OpenStackSwiftConnection):
     def get_endpoint(self):
         region = self._ex_force_service_region.upper()
 
-        if self.use_internal_url:
-            endpoint_type = "internal"
-        else:
-            endpoint_type = "external"
-
         if "2.0" in self._auth_version:
             ep = self.service_catalog.get_endpoint(
                 service_type="object-store",
                 name="cloudFiles",
                 region=region,
-                endpoint_type=endpoint_type,
+                endpoint_type="internal" if self.use_internal_url else "external",
             )
             cdn_ep = self.service_catalog.get_endpoint(
                 service_type="rax:object-cdn",
                 name="cloudFilesCDN",
                 region=region,
-                endpoint_type=endpoint_type,
+                # Cloud Files has no concept of an "internal" CDN.
+                endpoint_type="external",
             )
         else:
-            raise LibcloudError(
-                'Auth version "%s" not supported' % (self._auth_version)
-            )
+            raise LibcloudError('Auth version "%s" not supported' % (self._auth_version))
 
         # if this is a CDN request, return the cdn url instead
         if self.cdn_request:
@@ -257,7 +239,7 @@ class CloudFilesConnection(OpenStackSwiftConnection):
         if method in ["POST", "PUT"] and "Content-Type" not in headers:
             headers.update({"Content-Type": "application/json; charset=UTF-8"})
 
-        return super(CloudFilesConnection, self).request(
+        return super().request(
             action=action,
             params=params,
             data=data,
@@ -303,7 +285,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
 
         self.use_internal_url = use_internal_url
         OpenStackDriverMixin.__init__(self, **kwargs)
-        super(CloudFilesStorageDriver, self).__init__(
+        super().__init__(
             key=key,
             secret=secret,
             secure=secure,
@@ -329,9 +311,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
 
     def get_container(self, container_name):
         container_name_encoded = self._encode_container_name(container_name)
-        response = self.connection.request(
-            "/%s" % (container_name_encoded), method="HEAD"
-        )
+        response = self.connection.request("/%s" % (container_name_encoded), method="HEAD")
 
         if response.status == httplib.NO_CONTENT:
             container = self._headers_to_container(container_name, response.headers)
@@ -347,7 +327,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         object_name_encoded = self._encode_object_name(object_name)
 
         response = self.connection.request(
-            "/%s/%s" % (container_name_encoded, object_name_encoded), method="HEAD"
+            "/{}/{}".format(container_name_encoded, object_name_encoded), method="HEAD"
         )
         if response.status in [httplib.OK, httplib.NO_CONTENT]:
             obj = self._headers_to_object(object_name, container, response.headers)
@@ -371,15 +351,13 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
                 cdn_url = response.headers["x-cdn-uri"]
             return cdn_url
         elif response.status == httplib.NOT_FOUND:
-            raise ContainerDoesNotExistError(
-                value="", container_name=container.name, driver=self
-            )
+            raise ContainerDoesNotExistError(value="", container_name=container.name, driver=self)
 
         raise LibcloudError("Unexpected status code: %s" % (response.status))
 
     def get_object_cdn_url(self, obj):
         container_cdn_url = self.get_container_cdn_url(container=obj.container)
-        return "%s/%s" % (container_cdn_url, obj.name)
+        return "{}/{}".format(container_cdn_url, obj.name)
 
     def enable_container_cdn(self, container, ex_ttl=None):
         """
@@ -403,9 +381,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
 
     def create_container(self, container_name):
         container_name_encoded = self._encode_container_name(container_name)
-        response = self.connection.request(
-            "/%s" % (container_name_encoded), method="PUT"
-        )
+        response = self.connection.request("/%s" % (container_name_encoded), method="PUT")
 
         if response.status == httplib.CREATED:
             # Accepted mean that container is not yet created but it will be
@@ -440,7 +416,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         container_name = obj.container.name
         object_name = obj.name
         response = self.connection.request(
-            "/%s/%s" % (container_name, object_name), method="GET", raw=True
+            "/{}/{}".format(container_name, object_name), method="GET", raw=True
         )
 
         return self._get_object(
@@ -461,7 +437,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         container_name = obj.container.name
         object_name = obj.name
         response = self.connection.request(
-            "/%s/%s" % (container_name, object_name), method="GET", raw=True
+            "/{}/{}".format(container_name, object_name), method="GET", raw=True
         )
 
         return self._get_object(
@@ -490,7 +466,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         object_name = obj.name
         headers = {"Range": self._get_standard_range_str(start_bytes, end_bytes)}
         response = self.connection.request(
-            "/%s/%s" % (container_name, object_name),
+            "/{}/{}".format(container_name, object_name),
             method="GET",
             headers=headers,
             raw=True,
@@ -511,15 +487,13 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
             success_status_code=httplib.PARTIAL_CONTENT,
         )
 
-    def download_object_range_as_stream(
-        self, obj, start_bytes, end_bytes=None, chunk_size=None
-    ):
+    def download_object_range_as_stream(self, obj, start_bytes, end_bytes=None, chunk_size=None):
         self._validate_start_and_end_bytes(start_bytes=start_bytes, end_bytes=end_bytes)
         container_name = obj.container.name
         object_name = obj.name
         headers = {"Range": self._get_standard_range_str(start_bytes, end_bytes)}
         response = self.connection.request(
-            "/%s/%s" % (container_name, object_name),
+            "/{}/{}".format(container_name, object_name),
             headers=headers,
             method="GET",
             raw=True,
@@ -560,9 +534,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
             headers=headers,
         )
 
-    def upload_object_via_stream(
-        self, iterator, container, object_name, extra=None, headers=None
-    ):
+    def upload_object_via_stream(self, iterator, container, object_name, extra=None, headers=None):
         if isinstance(iterator, file):
             iterator = iter(iterator)
 
@@ -579,15 +551,13 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         object_name = self._encode_object_name(obj.name)
 
         response = self.connection.request(
-            "/%s/%s" % (container_name, object_name), method="DELETE"
+            "/{}/{}".format(container_name, object_name), method="DELETE"
         )
 
         if response.status == httplib.NO_CONTENT:
             return True
         elif response.status == httplib.NOT_FOUND:
-            raise ObjectDoesNotExistError(
-                value="", object_name=object_name, driver=self
-            )
+            raise ObjectDoesNotExistError(value="", object_name=object_name, driver=self)
 
         raise LibcloudError("Unexpected status code: %s" % (response.status))
 
@@ -605,7 +575,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
 
         # pylint: disable=unexpected-keyword-arg
         response = self.connection.request(
-            "/%s/%s" % (container_name, object_name),
+            "/{}/{}".format(container_name, object_name),
             method="DELETE",
             headers=headers,
             cdn_request=True,
@@ -622,9 +592,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         response = self.connection.request("", method="HEAD")
 
         if response.status == httplib.NO_CONTENT:
-            container_count = response.headers.get(
-                "x-account-container-count", "unknown"
-            )
+            container_count = response.headers.get("x-account-container-count", "unknown")
             object_count = response.headers.get("x-account-object-count", "unknown")
             bytes_used = response.headers.get("x-account-bytes-used", "unknown")
             temp_url_key = response.headers.get("x-account-meta-temp-url-key", None)
@@ -730,9 +698,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         headers = {"X-Account-Meta-Temp-URL-Key": key}
 
         # pylint: disable=unexpected-keyword-arg
-        response = self.connection.request(
-            "", method="POST", headers=headers, cdn_request=False
-        )
+        response = self.connection.request("", method="POST", headers=headers, cdn_request=False)
 
         return response.status in [
             httplib.OK,
@@ -763,7 +729,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         # pylint: disable=no-member
         self.connection._populate_hosts_and_request_paths()
         expires = int(time() + timeout)
-        path = "%s/%s/%s" % (self.connection.request_path, obj.container.name, obj.name)
+        path = "{}/{}/{}".format(self.connection.request_path, obj.container.name, obj.name)
         try:
             key = self.ex_get_meta_data()["temp_url_key"]
             assert key is not None
@@ -775,11 +741,11 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
                 + "ex_set_account_metadata_temp_url_key before "
                 + "you can use this method."
             )
-        hmac_body = "%s\n%s\n%s" % (method, expires, path)
+        hmac_body = "{}\n{}\n{}".format(method, expires, path)
         sig = hmac.new(b(key), b(hmac_body), sha1).hexdigest()
         params = urlencode({"temp_url_sig": sig, "temp_url_expires": expires})
 
-        temp_url = "https://%s/%s/%s?%s" % (
+        temp_url = "https://{}/{}/{}?{}".format(
             self.connection.host + self.connection.request_path,
             obj.container.name,
             obj.name,
@@ -788,9 +754,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
 
         return temp_url
 
-    def _upload_object_part(
-        self, container, object_name, part_number, iterator, verify_hash=True
-    ):
+    def _upload_object_part(self, container, object_name, part_number, iterator, verify_hash=True):
         part_name = object_name + "/%08d" % part_number
         extra = {"content_type": "application/octet-stream"}
 
@@ -802,21 +766,18 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
             verify_hash=verify_hash,
         )
 
-    def _upload_object_manifest(
-        self, container, object_name, extra=None, verify_hash=True
-    ):
+    def _upload_object_manifest(self, container, object_name, extra=None, verify_hash=True):
         extra = extra or {}
         meta_data = extra.get("meta_data")
 
         container_name_encoded = self._encode_container_name(container.name)
         object_name_encoded = self._encode_object_name(object_name)
-        request_path = "/%s/%s" % (container_name_encoded, object_name_encoded)
+        request_path = "/{}/{}".format(container_name_encoded, object_name_encoded)
 
         # pylint: disable=no-member
         headers = {
             "X-Auth-Token": self.connection.auth_token,
-            "X-Object-Manifest": "%s/%s/"
-            % (container_name_encoded, object_name_encoded),
+            "X-Object-Manifest": "{}/{}/".format(container_name_encoded, object_name_encoded),
         }
 
         data = ""
@@ -834,9 +795,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
 
             if object_hash != data_hash:
                 raise ObjectHashMismatchError(
-                    value=(
-                        "MD5 hash checksum does not match (expected=%s, " + "actual=%s)"
-                    )
+                    value=("MD5 hash checksum does not match (expected=%s, " + "actual=%s)")
                     % (data_hash, object_hash),
                     object_name=object_name,
                     driver=self,
@@ -880,9 +839,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
 
         while True:
             container_name_encoded = self._encode_container_name(container.name)
-            response = self.connection.request(
-                "/%s" % (container_name_encoded), params=params
-            )
+            response = self.connection.request("/%s" % (container_name_encoded), params=params)
 
             if response.status == httplib.NO_CONTENT:
                 # Empty or non-existent container
@@ -926,7 +883,7 @@ class CloudFilesStorageDriver(StorageDriver, OpenStackDriverMixin):
         if content_disposition is not None:
             headers["Content-Disposition"] = content_disposition
 
-        request_path = "/%s/%s" % (container_name_encoded, object_name_encoded)
+        request_path = "/{}/{}".format(container_name_encoded, object_name_encoded)
         result_dict = self._upload_object(
             object_name=object_name,
             content_type=content_type,
@@ -1081,10 +1038,8 @@ class OpenStackSwiftStorageDriver(CloudFilesStorageDriver):
 
     # TODO: Reverse the relationship - Swift -> CloudFiles
 
-    def __init__(
-        self, key, secret=None, secure=True, host=None, port=None, region=None, **kwargs
-    ):
-        super(OpenStackSwiftStorageDriver, self).__init__(
+    def __init__(self, key, secret=None, secure=True, host=None, port=None, region=None, **kwargs):
+        super().__init__(
             key=key,
             secret=secret,
             secure=secure,
@@ -1095,7 +1050,7 @@ class OpenStackSwiftStorageDriver(CloudFilesStorageDriver):
         )
 
 
-class FileChunkReader(object):
+class FileChunkReader:
     def __init__(self, file_path, chunk_size):
         self.file_path = file_path
         self.total = os.path.getsize(file_path)
@@ -1127,7 +1082,7 @@ class FileChunkReader(object):
         return self.next()
 
 
-class ChunkStreamReader(object):
+class ChunkStreamReader:
     def __init__(self, file_path, start_block, end_block, chunk_size):
         self.fd = open(file_path, "rb")
         self.fd.seek(start_block)
