@@ -15,37 +15,33 @@
 
 # pylint: disable=unexpected-keyword-arg
 
-import base64
-import codecs
+import os
 import hmac
 import time
+import base64
+import codecs
 from hashlib import sha1
 
-from libcloud.utils.py3 import ET
+from libcloud.utils.py3 import ET, b, httplib, tostring, urlquote, urlencode
+from libcloud.utils.xml import findtext, fixxpath
+from libcloud.common.base import RawResponse, XmlResponse, ConnectionUserAndKey
+from libcloud.utils.files import read_in_chunks
+from libcloud.common.types import LibcloudError, InvalidCredsError, MalformedResponseError
+from libcloud.storage.base import Object, Container, StorageDriver
+from libcloud.storage.types import (
+    ContainerError,
+    ObjectDoesNotExistError,
+    ObjectHashMismatchError,
+    ContainerIsNotEmptyError,
+    InvalidContainerNameError,
+    ContainerDoesNotExistError,
+)
 
 try:
     from lxml.etree import Element, SubElement
 except ImportError:
     from xml.etree.ElementTree import Element, SubElement
 
-from libcloud.utils.py3 import httplib
-from libcloud.utils.py3 import urlquote
-from libcloud.utils.py3 import urlencode
-from libcloud.utils.py3 import b
-from libcloud.utils.py3 import tostring
-from libcloud.utils.py3 import PY3
-from libcloud.utils.xml import fixxpath, findtext
-from libcloud.utils.files import read_in_chunks
-from libcloud.common.types import InvalidCredsError, LibcloudError
-from libcloud.common.base import ConnectionUserAndKey, RawResponse, XmlResponse
-from libcloud.common.types import MalformedResponseError
-from libcloud.storage.base import Object, Container, StorageDriver
-from libcloud.storage.types import ContainerError
-from libcloud.storage.types import ContainerIsNotEmptyError
-from libcloud.storage.types import InvalidContainerNameError
-from libcloud.storage.types import ContainerDoesNotExistError
-from libcloud.storage.types import ObjectDoesNotExistError
-from libcloud.storage.types import ObjectHashMismatchError
 
 __all__ = [
     "OSSStorageDriver",
@@ -82,11 +78,8 @@ class OSSResponse(XmlResponse):
             return self.body
 
         try:
-            if PY3:
-                parser = ET.XMLParser(encoding="utf-8")
-                body = ET.XML(self.body.encode("utf-8"), parser=parser)
-            else:
-                body = ET.XML(self.body)
+            parser = ET.XMLParser(encoding="utf-8")
+            body = ET.XML(self.body.encode("utf-8"), parser=parser)
         except Exception:
             raise MalformedResponseError(
                 "Failed to parse XML", body=self.body, driver=self.connection.driver
@@ -98,8 +91,7 @@ class OSSResponse(XmlResponse):
             raise InvalidCredsError(self.body)
         elif self.status == httplib.MOVED_PERMANENTLY:
             raise LibcloudError(
-                "This bucket is located in a different "
-                + "region. Please use the correct driver.",
+                "This bucket is located in a different " + "region. Please use the correct driver.",
                 driver=OSSStorageDriver,
             )
         elif self.status == httplib.METHOD_NOT_ALLOWED:
@@ -128,9 +120,7 @@ class OSSConnection(ConnectionUserAndKey):
     rawResponseCls = OSSRawResponse
 
     @staticmethod
-    def _get_auth_signature(
-        method, headers, params, expires, secret_key, path, vendor_prefix
-    ):
+    def _get_auth_signature(method, headers, params, expires, secret_key, path, vendor_prefix):
         """
         Signature = base64(hmac-sha1(AccessKeySecret,
           VERB + "\n"
@@ -160,7 +150,7 @@ class OSSConnection(ConnectionUserAndKey):
 
         buf = []
         for key, value in sorted(vendor_headers.items()):
-            buf.append("%s:%s" % (key, value))
+            buf.append("{}:{}".format(key, value))
         header_string = "\n".join(buf)
 
         values_to_sign = []
@@ -204,7 +194,7 @@ class OSSConnection(ConnectionUserAndKey):
 
     def pre_connect_hook(self, params, headers):
         if self._container:
-            path = "/%s%s" % (self._container.name, self.action)
+            path = "/{}{}".format(self._container.name, self.action)
         else:
             path = self.action
 
@@ -230,18 +220,18 @@ class OSSConnection(ConnectionUserAndKey):
         raw=False,
         container=None,
     ):
-        self.host = "%s.%s" % (self._default_location, self._domain)
+        self.host = "{}.{}".format(self._default_location, self._domain)
         self._container = container
         if container and container.name:
             if "location" in container.extra:
-                self.host = "%s.%s.%s" % (
+                self.host = "{}.{}.{}".format(
                     container.name,
                     container.extra["location"],
                     self._domain,
                 )
             else:
-                self.host = "%s.%s" % (container.name, self.host)
-        return super(OSSConnection, self).request(
+                self.host = "{}.{}".format(container.name, self.host)
+        return super().request(
             action=action,
             params=params,
             data=data,
@@ -251,7 +241,7 @@ class OSSConnection(ConnectionUserAndKey):
         )
 
 
-class OSSMultipartUpload(object):
+class OSSMultipartUpload:
     """
     Class representing an Aliyun OSS multipart upload
     """
@@ -290,14 +280,10 @@ class OSSStorageDriver(StorageDriver):
     def iterate_containers(self):
         response = self.connection.request("/")
         if response.status == httplib.OK:
-            containers = self._to_containers(
-                obj=response.object, xpath="Buckets/Bucket"
-            )
+            containers = self._to_containers(obj=response.object, xpath="Buckets/Bucket")
             return containers
 
-        raise LibcloudError(
-            "Unexpected status code: %s" % (response.status), driver=self
-        )
+        raise LibcloudError("Unexpected status code: %s" % (response.status), driver=self)
 
     def iterate_container_objects(self, container, prefix=None, ex_prefix=None):
         """
@@ -333,13 +319,9 @@ class OSSStorageDriver(StorageDriver):
             response = self.connection.request("/", params=params, container=container)
 
             if response.status != httplib.OK:
-                raise LibcloudError(
-                    "Unexpected status code: %s" % (response.status), driver=self
-                )
+                raise LibcloudError("Unexpected status code: %s" % (response.status), driver=self)
 
-            objects = self._to_objs(
-                obj=response.object, xpath="Contents", container=container
-            )
+            objects = self._to_objs(obj=response.object, xpath="Contents", container=container)
             is_truncated = response.object.findtext(
                 fixxpath(xpath="IsTruncated", namespace=self.namespace)
             ).lower()
@@ -354,16 +336,12 @@ class OSSStorageDriver(StorageDriver):
         for container in self.iterate_containers():
             if container.name == container_name:
                 return container
-        raise ContainerDoesNotExistError(
-            value=None, driver=self, container_name=container_name
-        )
+        raise ContainerDoesNotExistError(value=None, driver=self, container_name=container_name)
 
     def get_object(self, container_name, object_name):
         container = self.get_container(container_name=container_name)
         object_path = self._get_object_path(container, object_name)
-        response = self.connection.request(
-            object_path, method="HEAD", container=container
-        )
+        response = self.connection.request(object_path, method="HEAD", container=container)
 
         if response.status == httplib.OK:
             obj = self._headers_to_object(
@@ -392,9 +370,7 @@ class OSSStorageDriver(StorageDriver):
             data = ""
 
         container = Container(name=container_name, extra=extra, driver=self)
-        response = self.connection.request(
-            "/", data=data, method="PUT", container=container
-        )
+        response = self.connection.request("/", data=data, method="PUT", container=container)
 
         if response.status == httplib.OK:
             return container
@@ -412,9 +388,7 @@ class OSSStorageDriver(StorageDriver):
                 driver=self,
             )
 
-        raise LibcloudError(
-            "Unexpected status code: %s" % (response.status), driver=self
-        )
+        raise LibcloudError("Unexpected status code: %s" % (response.status), driver=self)
 
     def delete_container(self, container):
         # Note: All the objects in the container must be deleted first
@@ -428,9 +402,7 @@ class OSSStorageDriver(StorageDriver):
                 driver=self,
             )
         elif response.status == httplib.NOT_FOUND:
-            raise ContainerDoesNotExistError(
-                value=None, driver=self, container_name=container.name
-            )
+            raise ContainerDoesNotExistError(value=None, driver=self, container_name=container.name)
 
         return False
 
@@ -488,9 +460,7 @@ class OSSStorageDriver(StorageDriver):
             verify_hash=verify_hash,
         )
 
-    def upload_object_via_stream(
-        self, iterator, container, object_name, extra=None, headers=None
-    ):
+    def upload_object_via_stream(self, iterator, container, object_name, extra=None, headers=None):
         method = "PUT"
         params = None
 
@@ -510,9 +480,7 @@ class OSSStorageDriver(StorageDriver):
 
     def delete_object(self, obj):
         object_path = self._get_object_path(obj.container, obj.name)
-        response = self.connection.request(
-            object_path, method="DELETE", container=obj.container
-        )
+        response = self.connection.request(object_path, method="DELETE", container=obj.container)
         if response.status == httplib.NO_CONTENT:
             return True
         elif response.status == httplib.NOT_FOUND:
@@ -543,7 +511,7 @@ class OSSStorageDriver(StorageDriver):
             being split by this delimiter
         :type delimiter: ``str``
 
-        :keyword max_uploads: The max uplod items returned for one request
+        :keyword max_uploads: The max upload items returned for one request
         :type max_uploads: ``int``
 
         :return: A generator of OSSMultipartUpload instances.
@@ -566,23 +534,17 @@ class OSSStorageDriver(StorageDriver):
             return node.findtext(fixxpath(xpath=text, namespace=self.namespace))
 
         while True:
-            response = self.connection.request(
-                request_path, params=params, container=container
-            )
+            response = self.connection.request(request_path, params=params, container=container)
 
             if response.status != httplib.OK:
                 raise LibcloudError(
-                    "Error fetching multipart uploads. "
-                    "Got code: %s" % response.status,
+                    "Error fetching multipart uploads. " "Got code: %s" % response.status,
                     driver=self,
                 )
 
             body = response.parse_body()
             # pylint: disable=maybe-no-member
-            for node in body.findall(
-                fixxpath(xpath="Upload", namespace=self.namespace)
-            ):
-
+            for node in body.findall(fixxpath(xpath="Upload", namespace=self.namespace)):
                 key = finder(node, "Key")
                 upload_id = finder(node, "UploadId")
                 initiated = finder(node, "Initiated")
@@ -591,9 +553,7 @@ class OSSStorageDriver(StorageDriver):
 
             # Check if this is the last entry in the listing
             # pylint: disable=maybe-no-member
-            is_truncated = body.findtext(
-                fixxpath(xpath="IsTruncated", namespace=self.namespace)
-            )
+            is_truncated = body.findtext(fixxpath(xpath="IsTruncated", namespace=self.namespace))
 
             if is_truncated.lower() == "false":
                 break
@@ -602,9 +562,7 @@ class OSSStorageDriver(StorageDriver):
             upload_marker = body.findtext(
                 fixxpath(xpath="NextUploadIdMarker", namespace=self.namespace)
             )
-            key_marker = body.findtext(
-                fixxpath(xpath="NextKeyMarker", namespace=self.namespace)
-            )
+            key_marker = body.findtext(fixxpath(xpath="NextKeyMarker", namespace=self.namespace))
 
             params["key-marker"] = key_marker
             params["upload-id-marker"] = upload_marker
@@ -622,9 +580,7 @@ class OSSStorageDriver(StorageDriver):
         """
 
         # Iterate through the container and delete the upload ids
-        for upload in self.ex_iterate_multipart_uploads(
-            container, prefix, delimiter=None
-        ):
+        for upload in self.ex_iterate_multipart_uploads(container, prefix, delimiter=None):
             object_path = self._get_object_path(container, upload.key)
             self._abort_multipart(object_path, upload.id, container=container)
 
@@ -632,6 +588,68 @@ class OSSStorageDriver(StorageDriver):
         name = urlquote(name)
         return name
 
+    def _upload_object(
+        self,
+        object_name,
+        content_type,
+        request_path,
+        request_method="PUT",
+        headers=None,
+        file_path=None,
+        stream=None,
+        chunked=False,
+        multipart=False,
+        container=None,
+    ):
+        """
+        Helper function for setting common request headers and calling the
+        passed in callback which uploads an object.
+        """
+        headers = headers or {}
+
+        if file_path and not os.path.exists(file_path):
+            raise OSError("File %s does not exist" % (file_path))
+
+        if stream is not None and not hasattr(stream, "next") and not hasattr(stream, "__next__"):
+            raise AttributeError("iterator object must implement next() " + "method.")
+
+        headers["Content-Type"] = self._determine_content_type(
+            content_type, object_name, file_path=file_path
+        )
+
+        if stream:
+            response = self.connection.request(
+                request_path,
+                method=request_method,
+                data=stream,
+                headers=headers,
+                raw=True,
+                container=container,
+            )
+            stream_hash, stream_length = self._hash_buffered_stream(
+                stream, self._get_hash_function()
+            )
+        else:
+            with open(file_path, "rb") as file_stream:
+                response = self.connection.request(
+                    request_path,
+                    method=request_method,
+                    data=file_stream,
+                    headers=headers,
+                    raw=True,
+                    container=container,
+                )
+            with open(file_path, "rb") as file_stream:
+                stream_hash, stream_length = self._hash_buffered_stream(
+                    file_stream, self._get_hash_function()
+                )
+
+        return {
+            "response": response,
+            "bytes_transferred": stream_length,
+            "data_hash": stream_hash,
+        }
+
     def _put_object(
         self,
         container,
@@ -677,6 +695,7 @@ class OSSStorageDriver(StorageDriver):
             headers=headers,
             file_path=file_path,
             stream=stream,
+            container=container,
         )
 
         response = result_dict["response"]
@@ -685,9 +704,9 @@ class OSSStorageDriver(StorageDriver):
 
         server_hash = headers["etag"].replace('"', "")
 
-        if verify_hash and result_dict["data_hash"] != server_hash:
+        if verify_hash and result_dict["data_hash"].upper() != server_hash.upper():
             raise ObjectHashMismatchError(
-                value="MD5 hash {0} checksum does not match {1}".format(
+                value="MD5 hash {} checksum does not match {}".format(
                     server_hash, result_dict["data_hash"]
                 ),
                 object_name=object_name,
@@ -756,9 +775,7 @@ class OSSStorageDriver(StorageDriver):
             (chunks, data_hash, bytes_transferred) = result
 
             # Commit the chunk info and complete the upload
-            etag = self._commit_multipart(
-                object_path, upload_id, chunks, container=container
-            )
+            etag = self._commit_multipart(object_path, upload_id, chunks, container=container)
         except Exception as e:
             # Amazon provides a mechanism for aborting an upload.
             self._abort_multipart(object_path, upload_id, container=container)
@@ -774,7 +791,7 @@ class OSSStorageDriver(StorageDriver):
         self, iterator, object_path, upload_id, calculate_hash=True, container=None
     ):
         """
-        Uploads data from an interator in fixed sized chunks to OSS
+        Uploads data from an iterator in fixed sized chunks to OSS
 
         :param iterator: The generator for fetching the upload data
         :type iterator: ``generator``
@@ -866,7 +883,7 @@ class OSSStorageDriver(StorageDriver):
 
         root = Element("CompleteMultipartUpload")
 
-        for (count, etag) in chunks:
+        for count, etag in chunks:
             part = SubElement(root, "Part")
             part_no = SubElement(part, "PartNumber")
             part_no.text = str(count)
@@ -886,7 +903,7 @@ class OSSStorageDriver(StorageDriver):
             element = response.object
             # pylint: disable=maybe-no-member
             code, message = response._parse_error_details(element=element)
-            msg = "Error in multipart commit: %s (%s)" % (message, code)
+            msg = "Error in multipart commit: {} ({})".format(message, code)
             raise LibcloudError(msg, driver=self)
 
         # Get the server's etag to be passed back to the caller
@@ -911,9 +928,7 @@ class OSSStorageDriver(StorageDriver):
 
         params = {"uploadId": upload_id}
         request_path = "?".join((object_path, urlencode(params)))
-        resp = self.connection.request(
-            request_path, method="DELETE", container=container
-        )
+        resp = self.connection.request(request_path, method="DELETE", container=container)
 
         if resp.status != httplib.NO_CONTENT:
             raise LibcloudError(
@@ -929,9 +944,7 @@ class OSSStorageDriver(StorageDriver):
             "creation_date": findtext(
                 element=element, xpath="CreationDate", namespace=self.namespace
             ),
-            "location": findtext(
-                element=element, xpath="Location", namespace=self.namespace
-            ),
+            "location": findtext(element=element, xpath="Location", namespace=self.namespace),
         }
 
         container = Container(
@@ -959,20 +972,14 @@ class OSSStorageDriver(StorageDriver):
                 "display_name": self._safe_decode(owner_display_name),
             }
         }
-        last_modified = findtext(
-            element=element, xpath="LastModified", namespace=self.namespace
-        )
+        last_modified = findtext(element=element, xpath="LastModified", namespace=self.namespace)
         extra = {"last_modified": last_modified}
 
-        name = self._safe_decode(
-            findtext(element=element, xpath="Key", namespace=self.namespace)
-        )
+        name = self._safe_decode(findtext(element=element, xpath="Key", namespace=self.namespace))
         obj = Object(
             name=name,
             size=int(findtext(element=element, xpath="Size", namespace=self.namespace)),
-            hash=findtext(
-                element=element, xpath="ETag", namespace=self.namespace
-            ).replace('"', ""),
+            hash=findtext(element=element, xpath="ETag", namespace=self.namespace).replace('"', ""),
             extra=extra,
             meta_data=meta_data,
             container=container,
@@ -983,7 +990,7 @@ class OSSStorageDriver(StorageDriver):
 
     def _safe_decode(self, encoded):
         """
-        Decode it as an escaped string and then treate the content as
+        Decode it as an escaped string and then treat the content as
         UTF-8 encoded.
         """
         try:
