@@ -19,30 +19,34 @@ Driver for Microsoft Azure Resource Manager (ARM) Virtual Machines provider.
 http://azure.microsoft.com/en-us/services/virtual-machines/
 """
 
-import base64
-import binascii
 import os
 import time
+import base64
+import binascii
 
-from libcloud.common.azure_arm import AzureResourceManagementConnection
-from libcloud.compute.providers import Provider
-from libcloud.compute.base import Node, NodeDriver, NodeLocation, NodeSize
-from libcloud.compute.base import NodeImage, StorageVolume, VolumeSnapshot
-from libcloud.compute.base import NodeAuthPassword, NodeAuthSSHKey
-from libcloud.compute.types import NodeState, StorageVolumeState, VolumeSnapshotState
-from libcloud.common.types import LibcloudError
-from libcloud.storage.types import ObjectDoesNotExistError
-from libcloud.common.exceptions import BaseHTTPError
-from libcloud.storage.drivers.azure_blobs import AzureBlobsStorageDriver
-from libcloud.utils.py3 import basestring
 from libcloud.utils import iso8601
-
+from libcloud.utils.py3 import parse_qs, urlparse, basestring
+from libcloud.common.types import LibcloudError
+from libcloud.compute.base import (
+    Node,
+    NodeSize,
+    NodeImage,
+    NodeDriver,
+    NodeLocation,
+    StorageVolume,
+    NodeAuthSSHKey,
+    VolumeSnapshot,
+    NodeAuthPassword,
+)
+from libcloud.compute.types import NodeState, StorageVolumeState, VolumeSnapshotState
+from libcloud.storage.types import ObjectDoesNotExistError
+from libcloud.common.azure_arm import AzureResourceManagementConnection
+from libcloud.common.exceptions import BaseHTTPError
+from libcloud.compute.providers import Provider
+from libcloud.storage.drivers.azure_blobs import AzureBlobsStorageDriver
 
 RESOURCE_API_VERSION = "2016-04-30-preview"
-DISK_API_VERSION = (
-    "2016-04-30-preview"  # need to upgrade and merge with DISK_RESIZE_API_VERSION
-)
-DISK_RESIZE_API_VERSION = "2018-06-01"
+DISK_API_VERSION = "2023-01-02"
 IMAGES_API_VERSION = "2015-06-15"
 INSTANCE_VIEW_API_VERSION = "2015-06-15"
 IP_API_VERSION = "2019-06-01"
@@ -60,6 +64,16 @@ VM_API_VERSION = "2021-11-01"
 VM_EXTENSION_API_VERSION = "2015-06-15"
 VM_SIZE_API_VERSION = "2015-06-15"  # this API is deprecated
 
+# If pagination code in the list_nodes() method has still not completed after this mount of
+# seconds, we will break early from while True loop to avoid infinite loop under edge conditions.
+# Keep in mind that we want this timeout relatively high since each `_to_node()` method call which
+# is called for each node can result in additional HTTP requests (to retrieve power state, nics,
+# etc).
+LIST_NODES_PAGINATION_TIMEOUT = 300
+
+# Pagination timeout for list_volumes() method.
+LIST_VOLUMES_PAGINATION_TIMEOUT = 300
+
 
 class AzureImage(NodeImage):
     """Represents a Marketplace node image that an Azure VM can boot from."""
@@ -70,9 +84,9 @@ class AzureImage(NodeImage):
         self.sku = sku
         self.version = version
         self.location = location
-        urn = "%s:%s:%s:%s" % (self.publisher, self.offer, self.sku, self.version)
-        name = "%s %s %s %s" % (self.publisher, self.offer, self.sku, self.version)
-        super(AzureImage, self).__init__(urn, name, driver)
+        urn = "{}:{}:{}:{}".format(self.publisher, self.offer, self.sku, self.version)
+        name = "{} {} {} {}".format(self.publisher, self.offer, self.sku, self.version)
+        super().__init__(urn, name, driver)
 
     def __repr__(self):
         return ("<AzureImage: id=%s, name=%s, location=%s>") % (
@@ -86,13 +100,13 @@ class AzureVhdImage(NodeImage):
     """Represents a VHD node image that an Azure VM can boot from."""
 
     def __init__(self, storage_account, blob_container, name, driver):
-        urn = "https://%s.blob%s/%s/%s" % (
+        urn = "https://{}.blob{}/{}/{}".format(
             storage_account,
             driver.connection.storage_suffix,
             blob_container,
             name,
         )
-        super(AzureVhdImage, self).__init__(urn, name, driver)
+        super().__init__(urn, name, driver)
 
     def __repr__(self):
         return ("<AzureVhdImage: id=%s, name=%s>") % (self.id, self.name)
@@ -112,13 +126,13 @@ class AzureComputeGalleryImage(NodeImage):
                 name,
             )
         )
-        super(AzureComputeGalleryImage, self).__init__(id, name, driver)
+        super().__init__(id, name, driver)
 
     def __repr__(self):
         return ("<AzureComputeGalleryImage: id=%s, name=%s>") % (self.id, self.name)
 
 
-class AzureResourceGroup(object):
+class AzureResourceGroup:
     """Represent an Azure resource group."""
 
     def __init__(self, id, name, location, extra):
@@ -135,7 +149,7 @@ class AzureResourceGroup(object):
         )
 
 
-class AzureNetworkSecurityGroup(object):
+class AzureNetworkSecurityGroup:
     """Represent an Azure network security group."""
 
     def __init__(self, id, name, location, extra):
@@ -152,7 +166,7 @@ class AzureNetworkSecurityGroup(object):
         )
 
 
-class AzureNetwork(object):
+class AzureNetwork:
     """Represent an Azure virtual network."""
 
     def __init__(self, id, name, location, extra):
@@ -169,7 +183,7 @@ class AzureNetwork(object):
         )
 
 
-class AzureSubnet(object):
+class AzureSubnet:
     """Represents a subnet of an Azure virtual network."""
 
     def __init__(self, id, name, extra):
@@ -181,7 +195,7 @@ class AzureSubnet(object):
         return ("<AzureSubnet: id=%s, name=%s ...>") % (self.id, self.name)
 
 
-class AzureNic(object):
+class AzureNic:
     """Represents an Azure virtual network interface controller (NIC)."""
 
     def __init__(self, id, name, location, extra):
@@ -194,7 +208,7 @@ class AzureNic(object):
         return ("<AzureNic: id=%s, name=%s ...>") % (self.id, self.name)
 
 
-class AzureIPAddress(object):
+class AzureIPAddress:
     """Represents an Azure public IP address resource."""
 
     def __init__(self, id, name, extra):
@@ -260,7 +274,7 @@ class AzureNodeDriver(NodeDriver):
         self.tenant_id = tenant_id
         self.subscription_id = subscription_id
         self.cloud_environment = kwargs.get("cloud_environment")
-        super(AzureNodeDriver, self).__init__(
+        super().__init__(
             key=key,
             secret=secret,
             secure=secure,
@@ -285,12 +299,8 @@ class AzureNodeDriver(NodeDriver):
         :rtype: ``list`` of :class:`.NodeLocation`
         """
 
-        action = "/subscriptions/%s/providers/Microsoft.Compute" % (
-            self.subscription_id
-        )
-        r = self.connection.request(
-            action, params={"api-version": LOCATIONS_API_VERSION}
-        )
+        action = "/subscriptions/%s/providers/Microsoft.Compute" % (self.subscription_id)
+        r = self.connection.request(action, params={"api-version": LOCATIONS_API_VERSION})
 
         for rt in r.object["resourceTypes"]:
             if rt["resourceType"] == "virtualMachines":
@@ -315,9 +325,9 @@ class AzureNodeDriver(NodeDriver):
                 location = self.default_location
             else:
                 raise ValueError("location is required.")
-        action = (
-            "/subscriptions/%s/providers/Microsoft"
-            ".Compute/locations/%s/vmSizes" % (self.subscription_id, location.id)
+        action = "/subscriptions/%s/providers/Microsoft" ".Compute/locations/%s/vmSizes" % (
+            self.subscription_id,
+            location.id,
         )
         r = self.connection.request(action, params={"api-version": VM_SIZE_API_VERSION})
         return [self._to_node_size(d) for d in r.object["value"]]
@@ -380,7 +390,7 @@ class AzureNodeDriver(NodeDriver):
                 else:
                     offers = [
                         (
-                            "%s/artifacttypes/vmimage/offers/%s" % (pub[0], ex_offer),
+                            "{}/artifacttypes/vmimage/offers/{}".format(pub[0], ex_offer),
                             ex_offer,
                         )
                     ]
@@ -389,15 +399,13 @@ class AzureNodeDriver(NodeDriver):
                     if not ex_sku:
                         skus = self.ex_list_skus(off[0])
                     else:
-                        skus = [("%s/skus/%s" % (off[0], ex_sku), ex_sku)]
+                        skus = [("{}/skus/{}".format(off[0], ex_sku), ex_sku)]
 
                     for sku in skus:
                         if not ex_version:
                             versions = self.ex_list_image_versions(sku[0])
                         else:
-                            versions = [
-                                ("%s/versions/%s" % (sku[0], ex_version), ex_version)
-                            ]
+                            versions = [("{}/versions/{}".format(sku[0], ex_version), ex_version)]
 
                         for v in versions:
                             images.append(
@@ -438,9 +446,7 @@ class AzureNodeDriver(NodeDriver):
             i = self.list_images(location, ex_publisher, ex_offer, ex_sku, ex_version)
             return i[0] if i else None
 
-    def list_nodes(
-        self, ex_resource_group=None, ex_fetch_nic=True, ex_fetch_power_state=True
-    ):
+    def list_nodes(self, ex_resource_group=None, ex_fetch_nic=True, ex_fetch_power_state=True):
         """
         List all nodes.
 
@@ -460,8 +466,10 @@ class AzureNodeDriver(NodeDriver):
 
         :return:  list of node objects
         :rtype: ``list`` of :class:`.Node`
-        """
 
+        NOTE: With the default arguments, the function may result in M * (1 + (N * 3)) HTTP
+        requests where M is number of API pages and N is number of nodes returned per page.
+        """
         if ex_resource_group:
             action = (
                 "/subscriptions/%s/resourceGroups/%s/"
@@ -469,17 +477,28 @@ class AzureNodeDriver(NodeDriver):
                 % (self.subscription_id, ex_resource_group)
             )
         else:
-            action = (
-                "/subscriptions/%s/providers/Microsoft.Compute/"
-                "virtualMachines" % (self.subscription_id)
+            action = "/subscriptions/%s/providers/Microsoft.Compute/" "virtualMachines" % (
+                self.subscription_id
             )
-        r = self.connection.request(action, params={"api-version": VM_API_VERSION})
-        return [
-            self._to_node(
-                n, fetch_nic=ex_fetch_nic, fetch_power_state=ex_fetch_power_state
+        params = {"api-version": VM_API_VERSION}
+
+        now_ts = int(time.time())
+        deadline_ts = now_ts + LIST_NODES_PAGINATION_TIMEOUT
+
+        nodes = []
+        while time.time() < deadline_ts:
+            r = self.connection.request(action, params=params)
+            nodes.extend(
+                self._to_node(n, fetch_nic=ex_fetch_nic, fetch_power_state=ex_fetch_power_state)
+                for n in r.object["value"]
             )
-            for n in r.object["value"]
-        ]
+            if not r.object.get("nextLink"):
+                # No next page
+                break
+            parsed_next_link = urlparse.urlparse(r.object["nextLink"])
+            params.update({k: v[0] for k, v in parse_qs(parsed_next_link.query).items()})
+            action = parsed_next_link.path
+        return nodes
 
     def create_node(
         self,
@@ -614,9 +633,7 @@ class AzureNodeDriver(NodeDriver):
         :rtype: :class:`.Node`
         """
         if not ex_use_managed_disks and ex_storage_account is None:
-            raise ValueError(
-                "ex_use_managed_disks is False, " "must provide ex_storage_account"
-            )
+            raise ValueError("ex_use_managed_disks is False, " "must provide ex_storage_account")
 
         if location is None:
             location = self.default_location
@@ -665,12 +682,9 @@ class AzureNodeDriver(NodeDriver):
                 storage_profile["osDisk"]["deleteOption"] = "Delete"
             if ex_use_managed_disks:
                 raise LibcloudError(
-                    "Creating managed OS disk from %s image "
-                    "type is not supported." % type(image)
+                    "Creating managed OS disk from %s image " "type is not supported." % type(image)
                 )
-        elif isinstance(image, AzureImage) or isinstance(
-            image, AzureComputeGalleryImage
-        ):
+        elif isinstance(image, AzureImage) or isinstance(image, AzureComputeGalleryImage):
             if isinstance(image, AzureImage):
                 imageReference = {
                     "publisher": image.publisher,
@@ -724,14 +738,10 @@ class AzureNodeDriver(NodeDriver):
         }
 
         if ex_disk_size:
-            data["properties"]["storageProfile"]["osDisk"].update(
-                {"diskSizeGB": ex_disk_size}
-            )
+            data["properties"]["storageProfile"]["osDisk"].update({"diskSizeGB": ex_disk_size})
 
         if ex_customdata:
-            data["properties"]["osProfile"]["customData"] = base64.b64encode(
-                ex_customdata
-            )
+            data["properties"]["osProfile"]["customData"] = base64.b64encode(ex_customdata)
 
         data["properties"]["osProfile"]["adminUsername"] = ex_user_name
 
@@ -783,9 +793,7 @@ class AzureNodeDriver(NodeDriver):
 
         target = "%s/restart" % node.id
         try:
-            self.connection.request(
-                target, params={"api-version": VM_API_VERSION}, method="POST"
-            )
+            self.connection.request(target, params={"api-version": VM_API_VERSION}, method="POST")
             return True
         except BaseHTTPError as h:
             if h.code == 202:
@@ -874,11 +882,7 @@ class AzureNodeDriver(NodeDriver):
                         break
                     except BaseHTTPError as h:
                         retries -= 1
-                        if (
-                            h.code == 400
-                            and h.message.startswith("[NicInUse]")
-                            and retries > 0
-                        ):
+                        if h.code == 400 and h.message.startswith("[NicInUse]") and retries > 0:
                             time.sleep(ex_poll_wait)
                         else:
                             raise
@@ -917,8 +921,11 @@ class AzureNodeDriver(NodeDriver):
         location=None,
         snapshot=None,
         ex_resource_group=None,
-        ex_account_type=None,
+        ex_sku_name=None,
         ex_tags=None,
+        ex_zones=None,
+        ex_iops=None,
+        ex_throughput=None,
     ):
         """
         Create a new managed volume.
@@ -939,13 +946,23 @@ class AzureNodeDriver(NodeDriver):
             create the volume. (required)
         :type ex_resource_group: ``str``
 
-        :param ex_account_type: The Storage Account type,
-            ``Standard_LRS``(HDD disks) or ``Premium_LRS``(SSD disks).
-        :type ex_account_type: ``str``
+        :param ex_sku_name: The Disk SKU name. Refer to the API reference for
+            options.
+        :type ex_sku_name: ``str``
 
         :param ex_tags: Optional tags to associate with this resource.
         :type ex_tags: ``dict``
 
+        :param ex_zones: The list of availability zones to create the volume
+            in. Options are any or all of ["1", "2", "3"]. (optional)
+        :type ex_zones: ``list`` of ``str``
+
+        :param ex_iops: The max IOPS this volume is capable of.
+        :type ex_iops: ``int``
+
+        :param ex_throughput: The max throughput of this volume in MBps.
+        :type ex_throughput: ``int``
+
         :return: The newly created volume.
         :rtype: :class:`StorageVolume`
         """
@@ -975,8 +992,17 @@ class AzureNodeDriver(NodeDriver):
             "tags": tags,
             "properties": {"creationData": creation_data, "diskSizeGB": size},
         }
-        if ex_account_type is not None:
-            data["properties"]["accountType"] = ex_account_type
+        if ex_sku_name is not None:
+            data["sku"] = {"name": ex_sku_name}
+
+        if ex_zones is not None:
+            data["zones"] = ex_zones
+
+        if ex_iops is not None:
+            data["properties"]["diskIopsReadWrite"] = ex_iops
+
+        if ex_throughput is not None:
+            data["properties"]["diskMBpsReadWrite"] = ex_throughput
 
         response = self.connection.request(
             action,
@@ -985,9 +1011,7 @@ class AzureNodeDriver(NodeDriver):
             data=data,
         )
 
-        return self._to_volume(
-            response.object, name=name, ex_resource_group=ex_resource_group
-        )
+        return self._to_volume(response.object, name=name, ex_resource_group=ex_resource_group)
 
     def list_volumes(self, ex_resource_group=None):
         """
@@ -1005,18 +1029,27 @@ class AzureNodeDriver(NodeDriver):
                 "/{resource_group}/providers/Microsoft.Compute/disks"
             )
         else:
-            action = (
-                "/subscriptions/{subscription_id}" "/providers/Microsoft.Compute/disks"
-            )
+            action = "/subscriptions/{subscription_id}" "/providers/Microsoft.Compute/disks"
 
         action = action.format(
             subscription_id=self.subscription_id, resource_group=ex_resource_group
         )
+        params = {"api-version": DISK_API_VERSION}
 
-        response = self.connection.request(
-            action, method="GET", params={"api-version": DISK_API_VERSION}
-        )
-        return [self._to_volume(volume) for volume in response.object["value"]]
+        now_ts = int(time.time())
+        deadline_ts = now_ts + LIST_VOLUMES_PAGINATION_TIMEOUT
+
+        volumes = []
+        while time.time() < deadline_ts:
+            response = self.connection.request(action, method="GET", params=params)
+            volumes.extend(self._to_volume(volume) for volume in response.object["value"])
+            if not response.object.get("nextLink"):
+                # No next page
+                break
+            parsed_next_link = urlparse.urlparse(response.object["nextLink"])
+            params.update({k: v[0] for k, v in parse_qs(parsed_next_link.query).items()})
+            action = parsed_next_link.path
+        return volumes
 
     def attach_volume(
         self,
@@ -1127,13 +1160,11 @@ class AzureNodeDriver(NodeDriver):
         response = self.connection.request(
             action,
             method="PUT",
-            params={"api-version": DISK_RESIZE_API_VERSION},
+            params={"api-version": DISK_API_VERSION},
             data=data,
         )
 
-        return self._to_volume(
-            response.object, name=volume.name, ex_resource_group=resource_group
-        )
+        return self._to_volume(response.object, name=volume.name, ex_resource_group=resource_group)
 
     def detach_volume(self, volume, ex_node=None):
         """
@@ -1229,9 +1260,7 @@ class AzureNodeDriver(NodeDriver):
             params={"api-version": SNAPSHOT_API_VERSION},
         )
 
-        return self._to_snapshot(
-            response.object, name=name, ex_resource_group=ex_resource_group
-        )
+        return self._to_snapshot(response.object, name=name, ex_resource_group=ex_resource_group)
 
     def list_volume_snapshots(self, volume):
         return [
@@ -1256,10 +1285,7 @@ class AzureNodeDriver(NodeDriver):
                 "/{resource_group}/providers/Microsoft.Compute/snapshots"
             )
         else:
-            action = (
-                "/subscriptions/{subscription_id}"
-                "/providers/Microsoft.Compute/snapshots"
-            )
+            action = "/subscriptions/{subscription_id}" "/providers/Microsoft.Compute/snapshots"
 
         action = action.format(
             subscription_id=self.subscription_id, resource_group=ex_resource_group
@@ -1406,9 +1432,7 @@ class AzureNodeDriver(NodeDriver):
         )
         return r.status in [200, 202, 204]
 
-    def ex_get_ratecard(
-        self, offer_durable_id, currency="USD", locale="en-US", region="US"
-    ):
+    def ex_get_ratecard(self, offer_durable_id, currency="USD", locale="en-US", region="US"):
         """
         Get rate card
 
@@ -1462,9 +1486,9 @@ class AzureNodeDriver(NodeDriver):
             else:
                 raise ValueError("location is required.")
 
-        action = (
-            "/subscriptions/%s/providers/Microsoft.Compute/"
-            "locations/%s/publishers" % (self.subscription_id, location.id)
+        action = "/subscriptions/%s/providers/Microsoft.Compute/" "locations/%s/publishers" % (
+            self.subscription_id,
+            location.id,
         )
         r = self.connection.request(action, params={"api-version": IMAGES_API_VERSION})
         return [(p["id"], p["name"]) for p in r.object]
@@ -1529,13 +1553,9 @@ class AzureNodeDriver(NodeDriver):
         """
 
         action = "/subscriptions/%s/resourceGroups/" % (self.subscription_id)
-        r = self.connection.request(
-            action, params={"api-version": RESOURCE_GROUP_API_VERSION}
-        )
+        r = self.connection.request(action, params={"api-version": RESOURCE_GROUP_API_VERSION})
         return [
-            AzureResourceGroup(
-                grp["id"], grp["name"], grp["location"], grp["properties"]
-            )
+            AzureResourceGroup(grp["id"], grp["name"], grp["location"], grp["properties"])
             for grp in r.object["value"]
         ]
 
@@ -1553,14 +1573,11 @@ class AzureNodeDriver(NodeDriver):
 
         action = (
             "/subscriptions/%s/resourceGroups/%s/providers/"
-            "Microsoft.Network/networkSecurityGroups"
-            % (self.subscription_id, resource_group)
+            "Microsoft.Network/networkSecurityGroups" % (self.subscription_id, resource_group)
         )
         r = self.connection.request(action, params={"api-version": NSG_API_VERSION})
         return [
-            AzureNetworkSecurityGroup(
-                net["id"], net["name"], net["location"], net["properties"]
-            )
+            AzureNetworkSecurityGroup(net["id"], net["name"], net["location"], net["properties"])
             for net in r.object["value"]
         ]
 
@@ -1643,9 +1660,7 @@ class AzureNodeDriver(NodeDriver):
         action = "/subscriptions/%s/providers/" "Microsoft.Network/virtualnetworks" % (
             self.subscription_id
         )
-        r = self.connection.request(
-            action, params={"api-version": VIRTUAL_NETWORK_API_VERSION}
-        )
+        r = self.connection.request(action, params={"api-version": VIRTUAL_NETWORK_API_VERSION})
         return [
             AzureNetwork(net["id"], net["name"], net["location"], net["properties"])
             for net in r.object["value"]
@@ -1664,10 +1679,7 @@ class AzureNodeDriver(NodeDriver):
 
         action = "%s/subnets" % (network.id)
         r = self.connection.request(action, params={"api-version": SUBNET_API_VERSION})
-        return [
-            AzureSubnet(net["id"], net["name"], net["properties"])
-            for net in r.object["value"]
-        ]
+        return [AzureSubnet(net["id"], net["name"], net["properties"]) for net in r.object["value"]]
 
     def ex_list_nics(self, resource_group=None):
         """
@@ -1689,8 +1701,7 @@ class AzureNodeDriver(NodeDriver):
         else:
             action = (
                 "/subscriptions/%s/resourceGroups/%s/providers"
-                "/Microsoft.Network/networkInterfaces"
-                % (self.subscription_id, resource_group)
+                "/Microsoft.Network/networkInterfaces" % (self.subscription_id, resource_group)
             )
         r = self.connection.request(action, params={"api-version": NIC_API_VERSION})
         return [self._to_nic(net) for net in r.object["value"]]
@@ -1816,8 +1827,7 @@ class AzureNodeDriver(NodeDriver):
         action = (
             "/subscriptions/%s/resourceGroups/%s/providers"
             "/Microsoft.Network/virtualNetworks/%s/"
-            "CheckIPAddressAvailability"
-            % (self.subscription_id, resource_group, network.name)
+            "CheckIPAddressAvailability" % (self.subscription_id, resource_group, network.name)
         )
         if ip_address is not None:
             params["ipAddress"] = ip_address
@@ -1893,8 +1903,7 @@ class AzureNodeDriver(NodeDriver):
 
         action = (
             "/subscriptions/%s/resourceGroups/%s/"
-            "providers/Microsoft.Network/publicIPAddresses"
-            % (self.subscription_id, resource_group)
+            "providers/Microsoft.Network/publicIPAddresses" % (self.subscription_id, resource_group)
         )
         r = self.connection.request(action, params={"api-version": IP_API_VERSION})
         return [self._to_ip_address(net) for net in r.object["value"]]
@@ -2002,8 +2011,7 @@ class AzureNodeDriver(NodeDriver):
 
         target = (
             "/subscriptions/%s/resourceGroups/%s/providers"
-            "/Microsoft.Network/networkInterfaces/%s"
-            % (self.subscription_id, resource_group, name)
+            "/Microsoft.Network/networkInterfaces/%s" % (self.subscription_id, resource_group, name)
         )
 
         data = {
@@ -2065,6 +2073,49 @@ class AzureNodeDriver(NodeDriver):
             method="PATCH",
         )
 
+    def ex_create_additional_capabilities(
+        self,
+        node,
+        additional_capabilities,
+        resource_group,
+    ):
+        """
+        Set the additional capabilities on a stopped node.
+
+        :param node: The node to be updated
+        :type node: :class:`.Node`
+
+        :param ex_additional_capabilities: Optional additional capabilities
+            allowing Ultra SSD and hibernation on this node.
+        :type ex_additional_capabilities: ``dict``
+
+        :param resource_group: The resource group of the node to be updated
+        :type resource_group: ``str``
+
+        :return: True if the update was successful, otherwise False
+        :rtype: ``bool``
+        """
+
+        target = (
+            "/subscriptions/%s/resourceGroups/%s/providers"
+            "/Microsoft.Compute/virtualMachines/%s"
+            % (self.subscription_id, resource_group, node.name)
+        )
+
+        data = {
+            "location": node.extra["location"],
+            "properties": {"additionalCapabilities": additional_capabilities},
+        }
+
+        r = self.connection.request(
+            target,
+            data=data,
+            params={"api-version": VM_API_VERSION},
+            method="PUT",
+        )
+
+        return r.status in [200, 202, 204]
+
     def start_node(self, node):
         """
         Start a stopped node.
@@ -2074,9 +2125,7 @@ class AzureNodeDriver(NodeDriver):
         """
 
         target = "%s/start" % node.id
-        r = self.connection.request(
-            target, params={"api-version": VM_API_VERSION}, method="POST"
-        )
+        r = self.connection.request(target, params={"api-version": VM_API_VERSION}, method="POST")
         return r.object
 
     def stop_node(self, node, ex_deallocate=True):
@@ -2097,9 +2146,7 @@ class AzureNodeDriver(NodeDriver):
             target = "%s/deallocate" % node.id
         else:
             target = "%s/powerOff" % node.id
-        r = self.connection.request(
-            target, params={"api-version": VM_API_VERSION}, method="POST"
-        )
+        r = self.connection.request(target, params={"api-version": VM_API_VERSION}, method="POST")
         return r.object
 
     def ex_start_node(self, node):
@@ -2233,14 +2280,14 @@ class AzureNodeDriver(NodeDriver):
             blobdriver = AzureBlobsStorageDriver(
                 storageAccount,
                 keys["key1"],
-                host="%s.blob%s" % (storageAccount, self.connection.storage_suffix),
+                host="{}.blob{}".format(storageAccount, self.connection.storage_suffix),
             )
             return blobdriver.delete_object(blobdriver.get_object(blobContainer, blob))
         except ObjectDoesNotExistError:
             return True
 
     def _ex_connection_class_kwargs(self):
-        kwargs = super(AzureNodeDriver, self)._ex_connection_class_kwargs()
+        kwargs = super()._ex_connection_class_kwargs()
         kwargs["tenant_id"] = self.tenant_id
         kwargs["subscription_id"] = self.subscription_id
         kwargs["cloud_environment"] = self.cloud_environment
@@ -2250,9 +2297,7 @@ class AzureNodeDriver(NodeDriver):
         state = NodeState.UNKNOWN
         try:
             action = "%s/InstanceView" % (data["id"])
-            r = self.connection.request(
-                action, params={"api-version": INSTANCE_VIEW_API_VERSION}
-            )
+            r = self.connection.request(action, params={"api-version": INSTANCE_VIEW_API_VERSION})
             for status in r.object["statuses"]:
                 if status["code"] in ["ProvisioningState/creating"]:
                     state = NodeState.PENDING
@@ -2292,14 +2337,10 @@ class AzureNodeDriver(NodeDriver):
             for nic in nics:
                 try:
                     n = self.ex_get_nic(nic["id"])
-                    priv = n.extra["ipConfigurations"][0]["properties"].get(
-                        "privateIPAddress"
-                    )
+                    priv = n.extra["ipConfigurations"][0]["properties"].get("privateIPAddress")
                     if priv:
                         private_ips.append(priv)
-                    pub = n.extra["ipConfigurations"][0]["properties"].get(
-                        "publicIPAddress"
-                    )
+                    pub = n.extra["ipConfigurations"][0]["properties"].get("publicIPAddress")
                     if pub:
                         pub_addr = self.ex_get_public_ip(pub["id"])
                         addr = pub_addr.extra.get("ipAddress")
@@ -2354,9 +2395,7 @@ class AzureNodeDriver(NodeDriver):
         )
 
     def _to_nic(self, data):
-        return AzureNic(
-            data["id"], data.get("name"), data.get("location"), data.get("properties")
-        )
+        return AzureNic(data["id"], data.get("name"), data.get("location"), data.get("properties"))
 
     def _to_ip_address(self, data):
         return AzureIPAddress(data["id"], data["name"], data["properties"])
