@@ -15,20 +15,17 @@
 
 import base64
 
+from libcloud.utils.py3 import b, httplib, urlparse
+from libcloud.common.base import JsonResponse, ConnectionUserAndKey
+from libcloud.container.base import Container, ContainerImage, ContainerDriver
+from libcloud.container.types import ContainerState
+from libcloud.container.providers import Provider
+
 try:
     import simplejson as json
 except Exception:
     import json
 
-from libcloud.utils.py3 import httplib, urlparse
-from libcloud.utils.py3 import b
-
-from libcloud.common.base import JsonResponse, ConnectionUserAndKey
-
-from libcloud.container.base import Container, ContainerDriver, ContainerImage
-
-from libcloud.container.providers import Provider
-from libcloud.container.types import ContainerState
 
 VALID_RESPONSE_CODES = [
     httplib.OK,
@@ -40,16 +37,16 @@ VALID_RESPONSE_CODES = [
 
 class RancherResponse(JsonResponse):
     def parse_error(self):
-        parsed = super(RancherResponse, self).parse_error()
+        parsed = super().parse_error()
         if "fieldName" in parsed:
-            return "Field %s is %s: %s - %s" % (
+            return "Field {} is {}: {} - {}".format(
                 parsed["fieldName"],
                 parsed["code"],
                 parsed["message"],
                 parsed["detail"],
             )
         else:
-            return "%s - %s" % (parsed["message"], parsed["detail"])
+            return "{} - {}".format(parsed["message"], parsed["detail"])
 
     def success(self):
         return self.status in VALID_RESPONSE_CODES
@@ -62,14 +59,13 @@ class RancherException(Exception):
         self.args = (code, message)
 
     def __str__(self):
-        return "%s %s" % (self.code, self.message)
+        return "{} {}".format(self.code, self.message)
 
     def __repr__(self):
-        return "RancherException %s %s" % (self.code, self.message)
+        return "RancherException {} {}".format(self.code, self.message)
 
 
 class RancherConnection(ConnectionUserAndKey):
-
     responseCls = RancherResponse
     timeout = 30
 
@@ -82,7 +78,7 @@ class RancherConnection(ConnectionUserAndKey):
         headers["Content-Type"] = "application/json"
         headers["Accept"] = "application/json"
         if self.key and self.user_id:
-            user_b64 = base64.b64encode(b("%s:%s" % (self.user_id, self.key)))
+            user_b64 = base64.b64encode(b("{}:{}".format(self.user_id, self.key)))
             headers["Authorization"] = "Basic %s" % (user_b64.decode("utf-8"))
         return headers
 
@@ -150,7 +146,7 @@ class RancherContainerDriver(ContainerDriver):
             host = "//" + host
         parsed = urlparse.urlparse(host)
 
-        super(RancherContainerDriver, self).__init__(
+        super().__init__(
             key=key,
             secret=secret,
             secure=False if parsed.scheme == "http" else secure,
@@ -221,7 +217,7 @@ class RancherContainerDriver(ContainerDriver):
             "rancherCompose": rancher_compose,
             "startOnCreate": start,
         }
-        data = json.dumps(dict((k, v) for (k, v) in payload.items() if v is not None))
+        data = json.dumps({k: v for (k, v) in payload.items() if v is not None})
         result = self.connection.request(
             "%s/environments" % self.baseuri, data=data, method="POST"
         ).object
@@ -237,9 +233,7 @@ class RancherContainerDriver(ContainerDriver):
 
         :rtype: ``dict``
         """
-        result = self.connection.request(
-            "%s/environments/%s" % (self.baseuri, env_id)
-        ).object
+        result = self.connection.request("{}/environments/{}".format(self.baseuri, env_id)).object
 
         return result
 
@@ -259,7 +253,7 @@ class RancherContainerDriver(ContainerDriver):
             search_list.append(f + "=" + v)
         search_items = "&".join(search_list)
         result = self.connection.request(
-            "%s/environments?%s" % (self.baseuri, search_items)
+            "{}/environments?{}".format(self.baseuri, search_items)
         ).object
 
         return result["data"]
@@ -277,7 +271,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "%s/environments/%s" % (self.baseuri, env_id), method="DELETE"
+            "{}/environments/{}".format(self.baseuri, env_id), method="DELETE"
         )
         return result.status in VALID_RESPONSE_CODES
 
@@ -294,7 +288,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "%s/environments/%s?action=activateservices" % (self.baseuri, env_id),
+            "{}/environments/{}?action=activateservices".format(self.baseuri, env_id),
             method="POST",
         )
         return result.status in VALID_RESPONSE_CODES
@@ -313,7 +307,7 @@ class RancherContainerDriver(ContainerDriver):
         """
 
         result = self.connection.request(
-            "%s/environments/%s?action=deactivateservices" % (self.baseuri, env_id),
+            "{}/environments/{}?action=deactivateservices".format(self.baseuri, env_id),
             method="POST",
         )
         return result.status in VALID_RESPONSE_CODES
@@ -425,9 +419,7 @@ class RancherContainerDriver(ContainerDriver):
             "vip": vip,
         }
 
-        data = json.dumps(
-            dict((k, v) for (k, v) in service_payload.items() if v is not None)
-        )
+        data = json.dumps({k: v for (k, v) in service_payload.items() if v is not None})
         result = self.connection.request(
             "%s/services" % self.baseuri, data=data, method="POST"
         ).object
@@ -443,9 +435,7 @@ class RancherContainerDriver(ContainerDriver):
 
         :rtype: ``dict``
         """
-        result = self.connection.request(
-            "%s/services/%s" % (self.baseuri, service_id)
-        ).object
+        result = self.connection.request("{}/services/{}".format(self.baseuri, service_id)).object
 
         return result
 
@@ -464,9 +454,7 @@ class RancherContainerDriver(ContainerDriver):
         for f, v in search_params.items():
             search_list.append(f + "=" + v)
         search_items = "&".join(search_list)
-        result = self.connection.request(
-            "%s/services?%s" % (self.baseuri, search_items)
-        ).object
+        result = self.connection.request("{}/services?{}".format(self.baseuri, search_items)).object
 
         return result["data"]
 
@@ -483,7 +471,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "%s/services/%s" % (self.baseuri, service_id), method="DELETE"
+            "{}/services/{}".format(self.baseuri, service_id), method="DELETE"
         )
         return result.status in VALID_RESPONSE_CODES
 
@@ -500,7 +488,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "%s/services/%s?action=activate" % (self.baseuri, service_id), method="POST"
+            "{}/services/{}?action=activate".format(self.baseuri, service_id), method="POST"
         )
         return result.status in VALID_RESPONSE_CODES
 
@@ -517,7 +505,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "%s/services/%s?action=deactivate" % (self.baseuri, service_id),
+            "{}/services/{}?action=deactivate".format(self.baseuri, service_id),
             method="POST",
         )
         return result.status in VALID_RESPONSE_CODES
@@ -595,9 +583,7 @@ class RancherContainerDriver(ContainerDriver):
 
         :rtype: :class:`libcloud.container.base.Container`
         """
-        result = self.connection.request(
-            "%s/containers/%s" % (self.baseuri, con_id)
-        ).object
+        result = self.connection.request("{}/containers/{}".format(self.baseuri, con_id)).object
 
         return self._to_container(result)
 
@@ -612,7 +598,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: :class:`libcloud.container.base.Container`
         """
         result = self.connection.request(
-            "%s/containers/%s?action=start" % (self.baseuri, container.id),
+            "{}/containers/{}?action=start".format(self.baseuri, container.id),
             method="POST",
         ).object
 
@@ -629,7 +615,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: :class:`libcloud.container.base.Container`
         """
         result = self.connection.request(
-            "%s/containers/%s?action=stop" % (self.baseuri, container.id), method="POST"
+            "{}/containers/{}?action=stop".format(self.baseuri, container.id), method="POST"
         ).object
 
         return self._to_container(result)
@@ -650,7 +636,7 @@ class RancherContainerDriver(ContainerDriver):
             search_list.append(f + "=" + v)
         search_items = "&".join(search_list)
         result = self.connection.request(
-            "%s/containers?%s" % (self.baseuri, search_items)
+            "{}/containers?{}".format(self.baseuri, search_items)
         ).object
 
         return result["data"]
@@ -666,7 +652,7 @@ class RancherContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "%s/containers/%s" % (self.baseuri, container.id), method="DELETE"
+            "{}/containers/{}".format(self.baseuri, container.id), method="DELETE"
         ).object
 
         return self._to_container(result)
