@@ -14,24 +14,24 @@
 # limitations under the License.
 
 from libcloud.utils.py3 import ET
-from libcloud.common.dimensiondata import DimensionDataConnection
-from libcloud.common.dimensiondata import DimensionDataPool
-from libcloud.common.dimensiondata import DimensionDataPoolMember
-from libcloud.common.dimensiondata import DimensionDataVirtualListener
-from libcloud.common.dimensiondata import DimensionDataVIPNode
-from libcloud.common.dimensiondata import DimensionDataDefaultHealthMonitor
-from libcloud.common.dimensiondata import DimensionDataPersistenceProfile
-from libcloud.common.dimensiondata import DimensionDataVirtualListenerCompatibility
-from libcloud.common.dimensiondata import DimensionDataDefaultiRule
-from libcloud.common.dimensiondata import API_ENDPOINTS
-from libcloud.common.dimensiondata import DEFAULT_REGION
-from libcloud.common.dimensiondata import TYPES_URN
+from libcloud.utils.xml import findall, findtext, fixxpath
 from libcloud.utils.misc import reverse_dict
-from libcloud.utils.xml import fixxpath, findtext, findall
-from libcloud.loadbalancer.types import State
-from libcloud.loadbalancer.base import Algorithm, Driver, LoadBalancer
-from libcloud.loadbalancer.base import Member
-from libcloud.loadbalancer.types import Provider
+from libcloud.loadbalancer.base import Driver, Member, Algorithm, LoadBalancer
+from libcloud.loadbalancer.types import State, Provider
+from libcloud.common.dimensiondata import (
+    TYPES_URN,
+    API_ENDPOINTS,
+    DEFAULT_REGION,
+    DimensionDataPool,
+    DimensionDataVIPNode,
+    DimensionDataConnection,
+    DimensionDataPoolMember,
+    DimensionDataDefaultiRule,
+    DimensionDataVirtualListener,
+    DimensionDataPersistenceProfile,
+    DimensionDataDefaultHealthMonitor,
+    DimensionDataVirtualListenerCompatibility,
+)
 
 
 class DimensionDataLBDriver(Driver):
@@ -78,13 +78,12 @@ class DimensionDataLBDriver(Driver):
         region=DEFAULT_REGION,
         **kwargs,
     ):
-
         if region not in API_ENDPOINTS and host is None:
             raise ValueError("Invalid region: %s, no host specified" % (region))
         if region is not None:
             self.selected_region = API_ENDPOINTS[region]
 
-        super(DimensionDataLBDriver, self).__init__(
+        super().__init__(
             key=key,
             secret=secret,
             secure=secure,
@@ -100,7 +99,7 @@ class DimensionDataLBDriver(Driver):
         Add the region to the kwargs before the connection is instantiated
         """
 
-        kwargs = super(DimensionDataLBDriver, self)._ex_connection_class_kwargs()
+        kwargs = super()._ex_connection_class_kwargs()
         kwargs["region"] = self.selected_region
         return kwargs
 
@@ -301,9 +300,7 @@ class DimensionDataLBDriver(Driver):
         :return: ``True`` if member detach was successful, otherwise ``False``.
         :rtype: ``bool``
         """
-        create_pool_m = ET.Element(
-            "removePoolMember", {"xmlns": TYPES_URN, "id": member.id}
-        )
+        create_pool_m = ET.Element("removePoolMember", {"xmlns": TYPES_URN, "id": member.id})
 
         result = self.connection.request_with_orgId_api_2(
             "networkDomainVip/removePoolMember",
@@ -440,9 +437,7 @@ class DimensionDataLBDriver(Driver):
         ET.SubElement(create_node_elm, "ipv4Address").text = ip
         ET.SubElement(create_node_elm, "status").text = "ENABLED"
         ET.SubElement(create_node_elm, "connectionLimit").text = str(connection_limit)
-        ET.SubElement(create_node_elm, "connectionRateLimit").text = str(
-            connection_rate_limit
-        )
+        ET.SubElement(create_node_elm, "connectionRateLimit").text = str(connection_rate_limit)
 
         response = self.connection.request_with_orgId_api_2(
             action="networkDomainVip/createNode",
@@ -457,9 +452,7 @@ class DimensionDataLBDriver(Driver):
                 node_id = info.get("value")
             if info.get("name") == "name":
                 node_name = info.get("value")
-        return DimensionDataVIPNode(
-            id=node_id, name=node_name, status=State.RUNNING, ip=ip
-        )
+        return DimensionDataVIPNode(id=node_id, name=node_name, status=State.RUNNING, ip=ip)
 
     def ex_update_node(self, node):
         """
@@ -472,12 +465,8 @@ class DimensionDataLBDriver(Driver):
         :rtype: ``DimensionDataNode``
         """
         create_node_elm = ET.Element("editNode", {"xmlns": TYPES_URN})
-        ET.SubElement(create_node_elm, "connectionLimit").text = str(
-            node.connection_limit
-        )
-        ET.SubElement(create_node_elm, "connectionRateLimit").text = str(
-            node.connection_rate_limit
-        )
+        ET.SubElement(create_node_elm, "connectionLimit").text = str(node.connection_limit)
+        ET.SubElement(create_node_elm, "connectionRateLimit").text = str(node.connection_rate_limit)
 
         self.connection.request_with_orgId_api_2(
             action="networkDomainVip/createNode",
@@ -500,9 +489,7 @@ class DimensionDataLBDriver(Driver):
         :rtype: ``DimensionDataNode``
         """
         create_node_elm = ET.Element("editNode", {"xmlns": TYPES_URN})
-        ET.SubElement(create_node_elm, "status").text = (
-            "ENABLED" if enabled is True else "DISABLED"
-        )
+        ET.SubElement(create_node_elm, "status").text = "ENABLED" if enabled is True else "DISABLED"
 
         self.connection.request_with_orgId_api_2(
             action="networkDomainVip/editNode",
@@ -637,7 +624,7 @@ class DimensionDataLBDriver(Driver):
 
         :param protocol: For STANDARD type, ANY, TCP or UDP
                          for PERFORMANCE_LAYER_4 choice of ANY, TCP, UDP, HTTP
-        :type  protcol: ``str``
+        :type  protocol: ``str``
 
         :param connection_limit: Maximum number
                                 of concurrent connections per sec
@@ -665,25 +652,17 @@ class DimensionDataLBDriver(Driver):
         ET.SubElement(create_node_elm, "type").text = listener_type
         ET.SubElement(create_node_elm, "protocol").text = protocol
         if listener_ip_address is not None:
-            ET.SubElement(create_node_elm, "listenerIpAddress").text = str(
-                listener_ip_address
-            )
+            ET.SubElement(create_node_elm, "listenerIpAddress").text = str(listener_ip_address)
         if port is not None:
             ET.SubElement(create_node_elm, "port").text = str(port)
         ET.SubElement(create_node_elm, "enabled").text = "true"
         ET.SubElement(create_node_elm, "connectionLimit").text = str(connection_limit)
-        ET.SubElement(create_node_elm, "connectionRateLimit").text = str(
-            connection_rate_limit
-        )
-        ET.SubElement(
-            create_node_elm, "sourcePortPreservation"
-        ).text = source_port_preservation
+        ET.SubElement(create_node_elm, "connectionRateLimit").text = str(connection_rate_limit)
+        ET.SubElement(create_node_elm, "sourcePortPreservation").text = source_port_preservation
         if pool is not None:
             ET.SubElement(create_node_elm, "poolId").text = pool.id
         if persistence_profile is not None:
-            ET.SubElement(
-                create_node_elm, "persistenceProfileId"
-            ).text = persistence_profile.id
+            ET.SubElement(create_node_elm, "persistenceProfileId").text = persistence_profile.id
         if fallback_persistence_profile is not None:
             ET.SubElement(
                 create_node_elm, "fallbackPersistenceProfileId"
@@ -746,9 +725,7 @@ class DimensionDataLBDriver(Driver):
         :return: Returns an instance of ``DimensionDataPool``
         :rtype: ``DimensionDataPool``
         """
-        pool = self.connection.request_with_orgId_api_2(
-            "networkDomainVip/pool/%s" % pool_id
-        ).object
+        pool = self.connection.request_with_orgId_api_2("networkDomainVip/pool/%s" % pool_id).object
         return self._to_pool(pool)
 
     def ex_update_pool(self, pool):
@@ -764,12 +741,8 @@ class DimensionDataLBDriver(Driver):
         """
         create_node_elm = ET.Element("editPool", {"xmlns": TYPES_URN})
 
-        ET.SubElement(create_node_elm, "loadBalanceMethod").text = str(
-            pool.load_balance_method
-        )
-        ET.SubElement(
-            create_node_elm, "serviceDownAction"
-        ).text = pool.service_down_action
+        ET.SubElement(create_node_elm, "loadBalanceMethod").text = str(pool.load_balance_method)
+        ET.SubElement(create_node_elm, "serviceDownAction").text = pool.service_down_action
         ET.SubElement(create_node_elm, "slowRampTime").text = str(pool.slow_ramp_time)
 
         response = self.connection.request_with_orgId_api_2(
@@ -858,9 +831,7 @@ class DimensionDataLBDriver(Driver):
         :rtype: ``bool``
         """
         # remove the pool member
-        destroy_request = ET.Element(
-            "removePoolMember", {"xmlns": TYPES_URN, "id": member.id}
-        )
+        destroy_request = ET.Element("removePoolMember", {"xmlns": TYPES_URN, "id": member.id})
 
         result = self.connection.request_with_orgId_api_2(
             action="networkDomainVip/removePoolMember",
@@ -928,9 +899,7 @@ class DimensionDataLBDriver(Driver):
         response_code = findtext(result, "responseCode", TYPES_URN)
         return response_code in ["IN_PROGRESS", "OK"]
 
-    def ex_wait_for_state(
-        self, state, func, poll_interval=2, timeout=60, *args, **kwargs
-    ):
+    def ex_wait_for_state(self, state, func, poll_interval=2, timeout=60, *args, **kwargs):
         """
         Wait for the function which returns a instance
         with field status to match
@@ -955,9 +924,7 @@ class DimensionDataLBDriver(Driver):
         :param  kwargs: The arguments for func
         :type   kwargs: Keyword arguments
         """
-        return self.connection.wait_for_state(
-            state, func, poll_interval, timeout, *args, **kwargs
-        )
+        return self.connection.wait_for_state(state, func, poll_interval, timeout, *args, **kwargs)
 
     def ex_get_default_health_monitors(self, network_domain_id):
         """
@@ -1067,12 +1034,8 @@ class DimensionDataLBDriver(Driver):
         return DimensionDataDefaultHealthMonitor(
             id=element.get("id"),
             name=findtext(element, "name", TYPES_URN),
-            node_compatible=bool(
-                findtext(element, "nodeCompatible", TYPES_URN) == "true"
-            ),
-            pool_compatible=bool(
-                findtext(element, "poolCompatible", TYPES_URN) == "true"
-            ),
+            node_compatible=bool(findtext(element, "nodeCompatible", TYPES_URN) == "true"),
+            pool_compatible=bool(findtext(element, "poolCompatible", TYPES_URN) == "true"),
         )
 
     def _to_nodes(self, object):
